local invTypeEnumToName =
{
    [0] = "INVTYPE_NON_EQUIP",
    [1] = "INVTYPE_HEAD",
    [2] = "INVTYPE_NECK",
    [3] = "INVTYPE_SHOULDER",
    [4] = "INVTYPE_BODY",
    [5] = "INVTYPE_CHEST",
    [6] = "INVTYPE_WAIST",
    [7] = "INVTYPE_LEGS",
    [8] = "INVTYPE_FEET",
    [9] = "INVTYPE_WRIST",
    [10] = "INVTYPE_HAND",
    [11] = "INVTYPE_FINGER",
    [12] = "INVTYPE_TRINKET",
    [13] = "INVTYPE_WEAPON",
    [14] = "INVTYPE_SHIELD",
    [15] = "INVTYPE_RANGED",
    [16] = "INVTYPE_CLOAK",
    [17] = "INVTYPE_2HWEAPON",
    [18] = "INVTYPE_BAG",
    [19] = "INVTYPE_TABARD",
    [20] = "INVTYPE_ROBE",
    [21] = "INVTYPE_WEAPONMAINHAND",
    [22] = "INVTYPE_WEAPONOFFHAND",
    [23] = "INVTYPE_HOLDABLE",
    [24] = "INVTYPE_AMMO",
    [25] = "INVTYPE_THROWN",
    [26] = "INVTYPE_RANGEDRIGHT",
    [27] = "INVTYPE_QUIVER",
    [28] = "INVTYPE_RELIC",
};

function ezCollections:GetItemSetData(unit, sourceItemID)
    local setID = ezCollections.ItemXItemSet[sourceItemID];
    local set = setID and ezCollections.ItemSet[setID];
    if not setID or not set then
        return;
    end
    local data =
    {
        SetID = setID,
        SetItems = set[1],
        SetSpellThresholds = set[2],
        EquippedItems = { },
        EquippedItemNames = { },
        EquippedItemCount = 0,
        MissingCache = nil,
    };
    for slot = 1, 19 do
        local equippedItem = GetInventoryItemID(unit, slot);
        if ezCollections.ItemXItemSet[equippedItem] == setID then
            local equippedInvType = select(9, GetItemInfo(equippedItem));
            if not equippedInvType then
                local info = ezCollections:GetSkinInfo(equippedItem);
                equippedInvType = info and invTypeEnumToName[info.InventoryType];
            end
            if equippedInvType then
                for index, setItem in ipairs(data.SetItems) do
                    local setItemInvType = select(9, GetItemInfo(setItem));
                    if not setItemInvType then
                        local info = ezCollections:GetSkinInfo(setItem);
                        setItemInvType = info and invTypeEnumToName[info.InventoryType];
                    end
                    if setItemInvType then
                        if equippedInvType == setItemInvType or equippedInvType == "INVTYPE_CHEST" and setItemInvType == "INVTYPE_ROBE" or equippedInvType == "INVTYPE_ROBE" and setItemInvType == "INVTYPE_CHEST" then
                            data.EquippedItems[index] = equippedItem;
                            data.EquippedItemNames[index] = GetItemInfo(equippedItem);
                            if not data.EquippedItemNames[index] then
                                data.MissingCache = true;
                                ezCollections:QueryItem(equippedItem);
                            end
                        end
                    else
                        data.MissingCache = true;
                        ezCollections:QueryItem(setItem);
                    end
                end
            else
                data.MissingCache = true;
                ezCollections:QueryItem(equippedItem);
            end
        end
    end
    for index, item in pairs(data.EquippedItems) do
        data.EquippedItemCount = data.EquippedItemCount + 1;
    end
    return data;
end

ezCollections.ItemSet =
{
    [1] = { { 11729, 11726, 11728, 11731, 11730 }, { 3, 2, 5, 4 } }, -- The Gladiator
    [41] = { { 12940, 12939 }, { 2 } }, -- Dal'Rend's Arms
    [65] = { { 13218, 13183 }, { 2 } }, -- Spider's Kiss
    [81] = { { 13390, 13388, 13391, 13392, 13389 }, { 2, 5, 4, 3, 3, 5 } }, -- The Postmaster
    [121] = { { 14637, 14636, 14640, 14638, 14641 }, { 2, 3, 4, 5 } }, -- Cadaverous Garb
    [122] = { { 14631, 14629, 14632, 14633, 14626 }, { 3, 2, 4, 5 } }, -- Necropile Raiment
    [123] = { { 14614, 14616, 14615, 14611, 14612 }, { 5, 4, 3, 2 } }, -- Bloodmail Regalia
    [124] = { { 14624, 14622, 14620, 14623, 14621 }, { 2, 3, 4, 5 } }, -- Deathbone Guardian
    [141] = { { 15053, 15054, 15055 }, { 3 } }, -- Volcanic Armor
    [142] = { { 15056, 15057, 15058, 21278 }, { 2, 3, 4 } }, -- Stormshroud Armor
    [143] = { { 15062, 15063 }, { 2 } }, -- Devilsaur Armor
    [144] = { { 15066, 15067 }, { 2 } }, -- Ironfeather Armor
    [161] = { { 10399, 10403, 10402, 10401, 10400 }, { 5, 3, 2, 4 } }, -- Defias Leather
    [162] = { { 10412, 10411, 10413, 10410, 6473 }, { 5, 4, 2, 3 } }, -- Embrace of the Viper
    [163] = { { 10329, 10332, 10328, 10331, 10330, 10333 }, { 2, 3, 4, 5, 6 } }, -- Chain of the Scarlet Crusade
    [181] = { { 16685, 16683, 16686, 16684, 16687, 16689, 16688, 16682 }, { 2, 6, 8, 4 } }, -- Magister's Regalia
    [182] = { { 16696, 16691, 16697, 16693, 16692, 16695, 16694, 16690 }, { 2, 6, 8, 4 } }, -- Vestments of the Devout
    [183] = { { 16702, 16703, 16699, 16701, 16700, 16704, 16698, 16705 }, { 2, 6, 8, 4 } }, -- Dreadmist Raiment
    [184] = { { 16713, 16711, 16710, 16721, 16708, 16709, 16712, 16707 }, { 2, 6, 8, 4 } }, -- Shadowcraft Armor
    [185] = { { 16716, 16715, 16714, 16720, 16706, 16718, 16719, 16717 }, { 2, 6, 8, 4, 4 } }, -- Wildheart Raiment
    [186] = { { 16680, 16675, 16681, 16677, 16674, 16678, 16679, 16676 }, { 2, 6, 8, 4 } }, -- Beaststalker Armor
    [187] = { { 16673, 16670, 16671, 16667, 16672, 16668, 16669, 16666 }, { 2, 6, 8, 4 } }, -- The Elements
    [188] = { { 16723, 16725, 16722, 16726, 16724, 16728, 16729, 16727 }, { 2, 6, 8, 4 } }, -- Lightforge Armor
    [189] = { { 16736, 16734, 16735, 16730, 16737, 16731, 16732, 16733 }, { 2, 6, 8, 4 } }, -- Battlegear of Valor
    [201] = { { 16802, 16799, 16795, 16800, 16801, 16796, 16797, 16798 }, { 3, 5, 8 } }, -- Arcanist Regalia
    [202] = { { 16811, 16813, 16817, 16812, 16814, 16816, 16815, 16819 }, { 3, 5, 8 } }, -- Vestments of Prophecy
    [203] = { { 16806, 16804, 16805, 16810, 16809, 16807, 16808, 16803 }, { 3, 5, 8 } }, -- Felheart Raiment
    [204] = { { 16827, 16824, 16825, 16820, 16821, 16826, 16822, 16823 }, { 3, 5, 8 } }, -- Nightslayer Armor
    [205] = { { 16828, 16829, 16830, 16833, 16831, 16834, 16835, 16836 }, { 5, 8, 3 } }, -- Cenarion Raiment
    [206] = { { 16851, 16849, 16850, 16845, 16848, 16852, 16846, 16847 }, { 3, 8, 5 } }, -- Giantstalker Armor
    [207] = { { 16838, 16837, 16840, 16841, 16844, 16839, 16842, 16843 }, { 5, 3, 8 } }, -- The Earthfury
    [208] = { { 16858, 16859, 16857, 16853, 16860, 16854, 16855, 16856 }, { 3, 5, 8 } }, -- Lawbringer Armor
    [209] = { { 16864, 16861, 16865, 16863, 16866, 16867, 16868, 16862 }, { 3, 5, 8 } }, -- Battlegear of Might
    [210] = { { 16818, 16918, 16912, 16914, 16917, 16913, 16915, 16916 }, { 3, 5, 8 } }, -- Netherwind Regalia
    [211] = { { 16925, 16926, 16919, 16921, 16920, 16922, 16924, 16923 }, { 5, 3, 8 } }, -- Vestments of Transcendence
    [212] = { { 16933, 16927, 16934, 16928, 16930, 16931, 16929, 16932 }, { 5, 8, 3 } }, -- Nemesis Raiment
    [213] = { { 16910, 16906, 16911, 16905, 16907, 16908, 16909, 16832 }, { 5, 3, 8 } }, -- Bloodfang Armor
    [214] = { { 16903, 16898, 16904, 16897, 16900, 16899, 16901, 16902 }, { 3, 5, 8 } }, -- Stormrage Raiment
    [215] = { { 16936, 16935, 16942, 16940, 16941, 16939, 16938, 16937 }, { 5, 8, 3 } }, -- Dragonstalker Armor
    [216] = { { 16944, 16943, 16950, 16945, 16948, 16949, 16947, 16946 }, { 3, 5, 8 } }, -- The Ten Storms
    [217] = { { 16952, 16951, 16958, 16955, 16956, 16954, 16957, 16953 }, { 5, 3, 8 } }, -- Judgement Armor
    [218] = { { 16959, 16966, 16964, 16963, 16962, 16961, 16965, 16960 }, { 3, 5, 8 } }, -- Battlegear of Wrath
    [221] = { { 7950, 7948, 7952, 7951, 7953, 7949 }, { 6 } }, -- Garb of Thero-shan
    [241] = { { 17082, 17064 }, { 2 } }, -- Shard of the Gods
    [261] = { { 18203, 18202 }, { 2 } }, -- Spirit of Eskhandar
    [281] = { { 16509, 16510, 16513, 16515, 16514, 16516 }, { 2, 6, 4 } }, -- Champion's Battlegear
    [282] = { { 16405, 16406, 16430, 16431, 16429, 16432 }, { 2, 6, 4 } }, -- Lieutenant Commander's Battlegear
    [301] = { { 16519, 16518, 16522, 16523, 16521, 16524 }, { 2, 6, 4 } }, -- Champion's Earthshaker
    [321] = { { 12424, 12426, 12425, 12422, 12427, 12429, 12428 }, { 2, 4, 6 } }, -- Imperial Plate
    [341] = { { 16485, 16487, 16491, 16490, 16489, 16492 }, { 2, 4, 6 } }, -- Champion's Regalia
    [342] = { { 17616, 17617, 17612, 17611, 17613, 17610 }, { 2, 4, 6 } }, -- Champion's Raiment
    [343] = { { 16369, 16391, 16413, 16414, 16416, 16415 }, { 2, 4, 6 } }, -- Lieutenant Commander's Regalia
    [344] = { { 17594, 17596, 17600, 17599, 17598, 17601 }, { 4, 2, 6 } }, -- Lieutenant Commander's Raiment
    [345] = { { 17576, 17577, 17572, 17571, 17570, 17573 }, { 2, 6, 4 } }, -- Champion's Threads
    [346] = { { 17562, 17564, 17568, 17567, 17569, 17566 }, { 2, 6, 4 } }, -- Lieutenant Commander's Threads
    [347] = { { 16498, 16499, 16505, 16508, 16506, 16507 }, { 2, 6, 4 } }, -- Champion's Vestments
    [348] = { { 16392, 16396, 16417, 16419, 16420, 16418 }, { 2, 4, 6 } }, -- Lieutenant Commander's Vestments
    [361] = { { 16531, 16530, 16525, 16527, 16526, 16528 }, { 2, 4, 6 } }, -- Champion's Pursuit
    [362] = { { 16425, 16426, 16401, 16403, 16428, 16427 }, { 2, 4, 6 } }, -- Lieutenant Commander's Pursuit
    [381] = { { 16423, 16424, 16422, 16421, 16393, 16397 }, { 2, 4, 6 } }, -- Lieutenant Commander's Sanctuary
    [382] = { { 16494, 16496, 16504, 16502, 16503, 16501 }, { 4, 2, 6 } }, -- Champion's Sanctuary
    [383] = { { 16541, 16542, 16544, 16545, 16548, 16543 }, { 6, 3, 2 } }, -- Warlord's Battlegear
    [384] = { { 16477, 16478, 16480, 16483, 16484, 16479 }, { 2, 3, 6 } }, -- Field Marshal's Battlegear
    [386] = { { 16577, 16578, 16580, 16573, 16574, 16579 }, { 3, 2, 6 } }, -- Warlord's Earthshaker
    [387] = { { 16536, 16533, 16535, 16539, 16540, 16534 }, { 6, 2, 3 } }, -- Warlord's Regalia
    [388] = { { 16441, 16444, 16443, 16437, 16440, 16442 }, { 6, 2, 3 } }, -- Field Marshal's Regalia
    [389] = { { 17604, 17603, 17605, 17608, 17607, 17602 }, { 6, 2, 3 } }, -- Field Marshal's Raiment
    [390] = { { 17623, 17625, 17622, 17624, 17618, 17620 }, { 3, 6, 2 } }, -- Warlord's Raiment
    [391] = { { 17586, 17588, 17593, 17591, 17590, 17592 }, { 2, 3, 6 } }, -- Warlord's Threads
    [392] = { { 17581, 17580, 17583, 17584, 17579, 17578 }, { 6, 3, 2 } }, -- Field Marshal's Threads
    [393] = { { 16563, 16561, 16562, 16564, 16560, 16558 }, { 2, 3, 6 } }, -- Warlord's Vestments
    [394] = { { 16453, 16457, 16455, 16446, 16454, 16456 }, { 6, 3, 2 } }, -- Field Marshal's Vestments
    [395] = { { 16466, 16465, 16468, 16462, 16463, 16467 }, { 3, 6, 2 } }, -- Field Marshal's Pursuit
    [396] = { { 16569, 16571, 16567, 16565, 16566, 16568 }, { 2, 6, 3 } }, -- Warlord's Pursuit
    [397] = { { 16452, 16451, 16449, 16459, 16448, 16450 }, { 2, 6, 3 } }, -- Field Marshal's Sanctuary
    [398] = { { 16554, 16555, 16552, 16551, 16549, 16550 }, { 3, 6, 2 } }, -- Warlord's Sanctuary
    [401] = { { 16410, 16409, 16433, 16435, 16434, 16436 }, { 2, 2, 6, 4 } }, -- Lieutenant Commander's Aegis
    [402] = { { 16473, 16474, 16476, 16472, 16471, 16475 }, { 3, 2, 6 } }, -- Field Marshal's Aegis
    [421] = { { 19682, 19683, 19684 }, { 3 } }, -- Bloodvine Garb
    [441] = { { 19685, 19687, 19686 }, { 3 } }, -- Primal Batskin
    [442] = { { 19688, 19689 }, { 2, 2 } }, -- Blood Tiger Harness
    [443] = { { 19690, 19691, 19692 }, { 3 } }, -- Bloodsoul Embrace
    [444] = { { 19693, 19694, 19695 }, { 3 } }, -- The Darksoul
    [461] = { { 19865, 19866 }, { 2 } }, -- The Twin Blades of Hakkari
    [462] = { { 19893, 19905 }, { 2, 2 } }, -- Zanzil's Concentration
    [463] = { { 19896, 19910 }, { 2 } }, -- Primal Blessing
    [464] = { { 19873, 19912 }, { 2 } }, -- Overlord's Resolution
    [465] = { { 19863, 19920 }, { 2 } }, -- Prayer of the Primal
    [466] = { { 19898, 19925 }, { 2 } }, -- Major Mojo Infusion
    [467] = { { 20041, 20048, 20057 }, { 2, 3 } }, -- The Highlander's Resolution
    [468] = { { 20042, 20049, 20058 }, { 3, 2 } }, -- The Highlander's Resolve
    [469] = { { 20043, 20050, 20055 }, { 2, 3 } }, -- The Highlander's Determination
    [470] = { { 20044, 20051, 20056 }, { 3, 2 } }, -- The Highlander's Fortitude
    [471] = { { 20052, 20045, 20059 }, { 2, 3 } }, -- The Highlander's Purpose
    [472] = { { 20053, 20046, 20060 }, { 3, 2 } }, -- The Highlander's Will
    [473] = { { 20054, 20047, 20061 }, { 2, 3 } }, -- The Highlander's Intent
    [474] = { { 19951, 19577, 19824, 19823, 19822 }, { 2, 3, 5 } }, -- Vindicator's Battlegear
    [475] = { { 19952, 19588, 19827, 19826, 19825 }, { 2, 3, 5 } }, -- Freethinker's Armor
    [476] = { { 19609, 19956, 19830, 19829, 19828 }, { 2, 3, 5 } }, -- Augur's Regalia
    [477] = { { 19621, 19953, 19833, 19832, 19831 }, { 2, 3, 5 } }, -- Predator's Armor
    [478] = { { 19617, 19954, 19836, 19835, 19834 }, { 2, 3, 5 } }, -- Madcap's Outfit
    [479] = { { 19613, 19955, 19840, 19839, 19838 }, { 2, 5, 3 } }, -- Haruspex's Garb
    [480] = { { 19594, 19958, 19843, 19842, 19841 }, { 2, 5, 3 } }, -- Confessor's Raiment
    [481] = { { 19605, 19957, 19848, 19849, 20033 }, { 2, 3, 5 } }, -- Demoniac's Threads
    [482] = { { 19601, 19959, 19846, 19845, 20034 }, { 2, 3, 5 } }, -- Illusionist's Attire
    [483] = { { 20158, 20154, 20150 }, { 2, 3 } }, -- The Defiler's Determination
    [484] = { { 20195, 20199, 20203 }, { 2, 3 } }, -- The Defiler's Fortitude
    [485] = { { 20176, 20159, 20163 }, { 2, 3 } }, -- The Defiler's Intent
    [486] = { { 20186, 20190, 20194 }, { 2, 3 } }, -- The Defiler's Purpose
    [487] = { { 20204, 20208, 20212 }, { 2, 3 } }, -- The Defiler's Resolution
    [488] = { { 20167, 20171, 20175 }, { 2, 3 } }, -- The Defiler's Will
    [489] = { { 16984, 15050, 15052, 15051 }, { 2, 3, 4 } }, -- Black Dragon Mail
    [490] = { { 15045, 15046, 20296 }, { 2, 3 } }, -- Green Dragon Mail
    [491] = { { 15048, 20295, 15049 }, { 2, 3 } }, -- Blue Dragon Mail
    [492] = { { 20406, 20408, 20407 }, { 3 } }, -- Twilight Trappings
    [493] = { { 21355, 21353, 21354, 21356, 21357 }, { 5, 3, 3 } }, -- Genesis Raiment
    [494] = { { 21408, 21409, 21407 }, { 3 } }, -- Symbols of Unending Life
    [495] = { { 21394, 21392, 21393 }, { 3 } }, -- Battlegear of Unyielding Strength
    [496] = { { 21331, 21329, 21333, 21332, 21330 }, { 3, 5 } }, -- Conqueror's Battlegear
    [497] = { { 21359, 21360, 21361, 21362, 21364 }, { 3, 5 } }, -- Deathdealer's Embrace
    [498] = { { 21405, 21406, 21404 }, { 3 } }, -- Emblems of Veiled Shadows
    [499] = { { 21337, 21338, 21335, 21334, 21336 }, { 5, 3 } }, -- Doomcaller's Attire
    [500] = { { 21416, 21417, 21418 }, { 3 } }, -- Implements of Unspoken Names
    [501] = { { 21372, 21373, 21374, 21375, 21376 }, { 5, 3 } }, -- Stormcaller's Garb
    [502] = { { 21400, 21398, 21399 }, { 3 } }, -- Gift of the Gathering Storm
    [503] = { { 21344, 21347, 21346, 21343, 21345 }, { 3, 5 } }, -- Enigma Vestments
    [504] = { { 21414, 21413, 21415 }, { 3 } }, -- Trappings of Vaulted Secrets
    [505] = { { 21389, 21387, 21388, 21390, 21391 }, { 3, 5 } }, -- Avenger's Battlegear
    [506] = { { 21397, 21395, 21396 }, { 3 } }, -- Battlegear of Eternal Justice
    [507] = { { 21349, 21350, 21348, 21352, 21351 }, { 3, 5 } }, -- Garments of the Oracle
    [508] = { { 21410, 21411, 21412 }, { 3 } }, -- Finery of Infinite Wisdom
    [509] = { { 21366, 21365, 21370, 21368, 21367 }, { 3, 5 } }, -- Striker's Garb
    [510] = { { 21403, 21401, 21402 }, { 3 } }, -- Trappings of the Unseen Path
    [511] = { { 21994, 21995, 21996, 21997, 21998, 21999, 22000, 22001 }, { 6, 2, 4, 8 } }, -- Battlegear of Heroism
    [512] = { { 22002, 22003, 22004, 22005, 22006, 22007, 22008, 22009 }, { 6, 2, 4, 8 } }, -- Darkmantle Armor
    [513] = { { 22106, 22107, 22108, 22109, 22110, 22111, 22112, 22113 }, { 6, 6, 2, 4, 8 } }, -- Feralheart Raiment
    [514] = { { 22078, 22079, 22080, 22081, 22082, 22083, 22084, 22085 }, { 6, 2, 4, 8 } }, -- Vestments of the Virtuous
    [515] = { { 22010, 22011, 22061, 22013, 22015, 22016, 22017, 22060 }, { 6, 2, 4, 8 } }, -- Beastmaster Armor
    [516] = { { 22086, 22087, 22088, 22089, 22090, 22091, 22092, 22093 }, { 6, 2, 4, 8 } }, -- Soulforge Armor
    [517] = { { 22062, 22063, 22064, 22065, 22066, 22067, 22068, 22069 }, { 8, 4, 2, 6 } }, -- Sorcerer's Regalia
    [518] = { { 22070, 22071, 22072, 22073, 22074, 22075, 22076, 22077 }, { 6, 2, 4, 8 } }, -- Deathmist Raiment
    [519] = { { 22095, 22096, 22097, 22098, 22099, 22100, 22101, 22102 }, { 6, 2, 4, 8 } }, -- The Five Thunders
    [520] = { { 22306, 22311, 22313, 22302, 22304, 22305, 22303, 22301 }, { 4, 8 } }, -- Ironweave Battlesuit
    [521] = { { 22492, 22494, 22493, 22490, 22489, 22491, 22488, 22495, 23064 }, { 4, 6, 2, 8 } }, -- Dreamwalker Raiment
    [522] = { { 22864, 22856, 22879, 22880, 23257, 23258 }, { 2, 4, 6 } }, -- Champion's Guard
    [523] = { { 22423, 22416, 22421, 22422, 22418, 22417, 22419, 22420, 23059 }, { 6, 2, 4, 8 } }, -- Dreadnaught's Battlegear
    [524] = { { 22483, 22476, 22481, 22478, 22477, 22479, 22480, 22482, 23060 }, { 4, 8, 2, 6 } }, -- Bonescythe Armor
    [525] = { { 22518, 22519, 22514, 22517, 22513, 22512, 22516, 22515, 23061 }, { 4, 8, 2, 6 } }, -- Vestments of Faith
    [526] = { { 22502, 22503, 22498, 22501, 22497, 22496, 22500, 22499, 23062 }, { 6, 2, 8, 4 } }, -- Frostfire Regalia
    [527] = { { 22468, 22470, 22469, 22466, 22465, 22467, 22464, 22471, 23065 }, { 6, 4, 2, 8 } }, -- The Earthshatterer
    [528] = { { 22430, 22431, 22426, 22428, 22427, 22429, 22425, 22424, 23066 }, { 8, 6, 2, 4 } }, -- Redemption Armor
    [529] = { { 22510, 22511, 22506, 22509, 22505, 22504, 22508, 22507, 23063 }, { 4, 8, 2, 6 } }, -- Plagueheart Raiment
    [530] = { { 22440, 22442, 22441, 22438, 22437, 22439, 22436, 22443, 23067 }, { 6, 8, 4, 2 } }, -- Cryptstalker Armor
    [533] = { { 23090, 23087, 23078 }, { 3 } }, -- Battlegear of Undead Slaying
    [534] = { { 23081, 23089, 23093 }, { 3 } }, -- Undead Slayer's Armor
    [535] = { { 23088, 23082, 23092 }, { 3 } }, -- Garb of the Undead Slayer
    [536] = { { 23091, 23084, 23085 }, { 3 } }, -- Regalia of Undead Cleansing
    [537] = { { 22868, 22858, 22872, 22873, 23244, 23243 }, { 2, 4, 6 } }, -- Champion's Battlearmor
    [538] = { { 22857, 22867, 22876, 22887, 23259, 23260 }, { 2, 4, 6 } }, -- Champion's Stormcaller
    [539] = { { 22863, 22852, 22877, 22878, 23253, 23254 }, { 2, 4, 6 } }, -- Champion's Refuge
    [540] = { { 22869, 22859, 22882, 22885, 23261, 23262 }, { 2, 4, 6 } }, -- Champion's Investiture
    [541] = { { 22865, 22855, 23255, 23256, 22881, 22884 }, { 6, 2, 4 } }, -- Champion's Dreadgear
    [542] = { { 22870, 22860, 23263, 23264, 22883, 22886 }, { 2, 6, 4 } }, -- Champion's Arcanum
    [543] = { { 22843, 22862, 23251, 23252, 22874, 22875 }, { 4, 6, 2 } }, -- Champion's Pursuance
    [544] = { { 23272, 23273, 23274, 23275, 23276, 23277 }, { 2, 6, 4 } }, -- Lieutenant Commander's Redoubt
    [545] = { { 23300, 23301, 23286, 23287, 23314, 23315 }, { 4, 6, 2 } }, -- Lieutenant Commander's Battlearmor
    [546] = { { 23304, 23305, 23290, 23291, 23318, 23319 }, { 2, 6, 4 } }, -- Lieutenant Commander's Arcanum
    [547] = { { 23296, 23297, 23282, 23283, 23310, 23311 }, { 2, 6, 4 } }, -- Lieutenant Commander's Dreadgear
    [548] = { { 23298, 23299, 23284, 23285, 23312, 23313 }, { 4, 6, 2 } }, -- Lieutenant Commander's Guard
    [549] = { { 23302, 23303, 23288, 23289, 23316, 23317 }, { 2, 4, 6 } }, -- Lieutenant Commander's Investiture
    [550] = { { 23292, 23293, 23278, 23279, 23306, 23307 }, { 6, 2, 4 } }, -- Lieutenant Commander's Pursuance
    [551] = { { 23294, 23295, 23280, 23281, 23308, 23309 }, { 6, 4, 2 } }, -- Lieutenant Commander's Refuge
    [552] = { { 21848, 21847, 21846 }, { 3 } }, -- Wrath of Spellfire
    [553] = { { 21871, 21869, 21870 }, { 3 } }, -- Shadow's Embrace
    [554] = { { 21875, 21874, 21873 }, { 3 } }, -- Primal Mooncloth
    [555] = { { 21855, 21854, 21852, 21851, 21849, 21853, 21850 }, { 2, 4 } }, -- Netherweave Vestments
    [556] = { { 21862, 21861, 21859, 21860 }, { 3 } }, -- Imbued Netherweave
    [557] = { { 21865, 21864, 21863 }, { 3 } }, -- Soulcloth Embrace
    [558] = { { 21868, 21866, 21867 }, { 3 } }, -- Arcanoweave Vestments
    [559] = { { 24266, 24262 }, { 2 } }, -- Spellstrike Infusion
    [560] = { { 23489, 23488, 23487, 23482, 23484 }, { 2, 4 } }, -- Fel Iron Plate
    [561] = { { 23490, 23491, 23493, 23494 }, { 4, 2 } }, -- Fel Iron Chain
    [562] = { { 23507, 23508, 23506 }, { 3 } }, -- Adamantite Battlegear
    [563] = { { 23509, 23512, 23511, 23510 }, { 3 } }, -- Enchanted Adamantite Armor
    [564] = { { 23513, 23516, 23514, 23515 }, { 3 } }, -- Flame Guard
    [565] = { { 23523, 23525, 23524 }, { 3 } }, -- Khorium Ward
    [566] = { { 23522, 23521, 23520, 33173 }, { 2 } }, -- Burning Rage
    [567] = { { 24544, 24549, 24545, 24547, 24546 }, { 4, 2 } }, -- Gladiator's Battlegear
    [568] = { { 24556, 24553, 24555, 24554, 24552 }, { 2, 4 } }, -- Gladiator's Dreadgear
    [569] = { { 23519, 23518, 23517 }, { 3 } }, -- Faith in Felsteel
    [570] = { { 24255, 24249 }, { 2 } }, -- The Unyielding
    [571] = { { 24264, 24261 }, { 2 } }, -- Whitemend Wisdom
    [572] = { { 24267, 24263 }, { 2 } }, -- Battlecast Garb
    [573] = { { 25685, 25686, 25687 }, { 3 } }, -- Fel Skin
    [574] = { { 25691, 25690, 25689 }, { 3 } }, -- Strength of the Clefthoof
    [575] = { { 25695, 25697, 25696 }, { 3 } }, -- Felstalker Armor
    [576] = { { 25694, 25693, 25692 }, { 3 } }, -- Fury of the Nether
    [577] = { { 25834, 25833, 25830, 25832, 25831 }, { 2, 4 } }, -- Gladiator's Vestments
    [578] = { { 25997, 26000, 25998, 26001, 25999 }, { 4, 2 } }, -- Gladiator's Earthshaker
    [579] = { { 25854, 25855, 25857, 25856, 25858 }, { 2, 4 } }, -- Gladiator's Regalia
    [580] = { { 27469, 27470, 27471, 27472, 27473 }, { 2, 4 } }, -- Gladiator's Thunderfist
    [581] = { { 27707, 27708, 27709, 27710, 27711 }, { 2, 4 } }, -- Gladiator's Raiment
    [582] = { { 27702, 27703, 27704, 27705, 27706 }, { 4, 2 } }, -- Gladiator's Aegis
    [583] = { { 27879, 27880, 27881, 27882, 27883 }, { 2, 4 } }, -- Gladiator's Vindication
    [584] = { { 28126, 28127, 28128, 28129, 28130 }, { 2, 4 } }, -- Gladiator's Sanctuary
    [585] = { { 28136, 28137, 28138, 28139, 28140 }, { 2, 4 } }, -- Gladiator's Wildhide
    [586] = { { 28334, 28335, 28331, 28332, 28333 }, { 2, 4 } }, -- Gladiator's Pursuit
    [587] = { { 28831, 28832, 28833, 28834, 28835 }, { 2, 4 } }, -- High Warlord's Aegis
    [588] = { { 28851, 28852, 28853, 28854, 28855 }, { 2, 4 } }, -- High Warlord's Battlegear
    [589] = { { 28679, 28680, 28681, 28724, 28683 }, { 2, 4 } }, -- Grand Marshal's Aegis
    [590] = { { 28699, 28700, 28701, 28702, 28703 }, { 2, 4 } }, -- Grand Marshal's Battlegear
    [591] = { { 28624, 28625, 28626, 28627, 28628 }, { 2, 4 } }, -- Grand Marshal's Dreadgear
    [592] = { { 28817, 28818, 28819, 28820, 28821 }, { 2, 4 } }, -- High Warlord's Dreadgear
    [593] = { { 28689, 28690, 28691, 28692, 28693 }, { 2, 4 } }, -- Grand Marshal's Earthshaker
    [594] = { { 28841, 28842, 28843, 28844, 28845 }, { 2, 4 } }, -- High Warlord's Earthshaker
    [595] = { { 28613, 28614, 28615, 28616, 28617 }, { 2, 4 } }, -- Grand Marshal's Pursuit
    [596] = { { 28805, 28806, 28807, 28808, 28809 }, { 2, 4 } }, -- High Warlord's Pursuit
    [597] = { { 28704, 28705, 28706, 28707, 28708 }, { 2, 4 } }, -- Grand Marshal's Raiment
    [598] = { { 28856, 28857, 28858, 28859, 28860 }, { 2, 4 } }, -- High Warlord's Raiment
    [599] = { { 28714, 28715, 28716, 28717, 28718 }, { 2, 4 } }, -- Grand Marshal's Regalia
    [600] = { { 28866, 28867, 28868, 28869, 28870 }, { 2, 4 } }, -- High Warlord's Regalia
    [601] = { { 28618, 28619, 28620, 28622, 28623 }, { 2, 4 } }, -- Grand Marshal's Sanctuary
    [602] = { { 28811, 28812, 28813, 28814, 28815 }, { 2, 4 } }, -- High Warlord's Sanctuary
    [603] = { { 28694, 28695, 28696, 28697, 28698 }, { 2, 4 } }, -- Grand Marshal's Thunderfist
    [604] = { { 28846, 28847, 28848, 28849, 28850 }, { 2, 4 } }, -- High Warlord's Thunderfist
    [605] = { { 28684, 28685, 28686, 28687, 28688 }, { 2, 4 } }, -- Grand Marshal's Vestments
    [606] = { { 28836, 28837, 28838, 28839, 28840 }, { 2, 4 } }, -- High Warlord's Vestments
    [607] = { { 28709, 28710, 28711, 28712, 28713 }, { 2, 4 } }, -- Grand Marshal's Vindication
    [608] = { { 28861, 28862, 28863, 28864, 28865 }, { 2, 4 } }, -- High Warlord's Vindication
    [609] = { { 28719, 28720, 28721, 28722, 28723 }, { 2, 4 } }, -- Grand Marshal's Wildhide
    [610] = { { 28871, 28872, 28873, 28874, 28875 }, { 2, 4 } }, -- High Warlord's Wildhide
    [611] = { { 25657, 25656, 25655, 25654 }, { 2, 4 } }, -- Felscale Armor
    [612] = { { 25661, 25659, 25662, 25660 }, { 4, 2 } }, -- Scaled Draenic Armor
    [613] = { { 25668, 25669, 25670, 25671 }, { 2, 4 } }, -- Thick Draenic Armor
    [614] = { { 25673, 25674, 25675, 25676 }, { 2, 4 } }, -- Wild Draenish Armor
    [615] = { { 30186, 30187, 30188, 30200, 30201 }, { 2, 4 } }, -- Gladiator's Felshroud
    [616] = { { 29516, 29517, 29515 }, { 3 } }, -- Netherscale Armor
    [617] = { { 29521, 29520, 29519 }, { 3 } }, -- Netherstrike Armor
    [618] = { { 29523, 29524, 29522 }, { 3 } }, -- Windhawk Armor
    [619] = { { 29527, 29526, 29525 }, { 3 } }, -- Primal Intent
    [620] = { { 27509, 28414, 27908, 27776, 28204 }, { 2, 4 } }, -- Assassination Armor
    [621] = { { 29046, 29045, 29044, 29048, 29047 }, { 2, 4 } }, -- Netherblade
    [622] = { { 30144, 30145, 30146, 30148, 30149 }, { 2, 4 } }, -- Deathmantle
    [623] = { { 28203, 27535, 28285, 27839, 27739 }, { 2, 4 } }, -- Righteous Armor
    [624] = { { 29062, 29061, 29065, 29063, 29064 }, { 2, 4 } }, -- Justicar Raiment
    [625] = { { 29066, 29068, 29067, 29069, 29070 }, { 2, 4 } }, -- Justicar Armor
    [626] = { { 29071, 29073, 29072, 29074, 29075 }, { 2, 4 } }, -- Justicar Battlegear
    [627] = { { 30134, 30135, 30136, 30137, 30138 }, { 2, 4 } }, -- Crystalforge Raiment
    [628] = { { 30123, 30125, 30124, 30126, 30127 }, { 2, 4 } }, -- Crystalforge Armor
    [629] = { { 30129, 30130, 30132, 30133, 30131 }, { 2, 4 } }, -- Crystalforge Battlegear
    [630] = { { 28231, 27510, 28349, 27909, 27802 }, { 2, 4 } }, -- Tidefury Raiment
    [631] = { { 29032, 29029, 29028, 29030, 29031 }, { 2, 4 } }, -- Cyclone Raiment
    [632] = { { 29033, 29035, 29034, 29036, 29037 }, { 4, 2 } }, -- Cyclone Regalia
    [633] = { { 29038, 29039, 29040, 29043, 29042 }, { 2, 4 } }, -- Cyclone Harness
    [634] = { { 30164, 30165, 30166, 30167, 30168 }, { 2, 4 } }, -- Cataclysm Raiment
    [635] = { { 30169, 30170, 30171, 30172, 30173 }, { 2, 4 } }, -- Cataclysm Regalia
    [636] = { { 30185, 30189, 30190, 30192, 30194 }, { 2, 4 } }, -- Cataclysm Harness
    [637] = { { 28348, 27468, 27873, 28202, 27737 }, { 2, 4 } }, -- Moonglade Raiment
    [638] = { { 29087, 29086, 29090, 29088, 29089 }, { 2, 4 } }, -- Malorne Raiment
    [639] = { { 29093, 29094, 29091, 29092, 29095 }, { 2, 4 } }, -- Malorne Regalia
    [640] = { { 29096, 29097, 29099, 29100, 29098 }, { 2, 2, 4, 4 } }, -- Malorne Harness
    [641] = { { 30222, 30223, 30228, 30229, 30230 }, { 2, 4 } }, -- Nordrassil Harness
    [642] = { { 30216, 30217, 30219, 30220, 30221 }, { 2, 4 } }, -- Nordrassil Raiment
    [643] = { { 30231, 30232, 30233, 30234, 30235 }, { 2, 4 } }, -- Nordrassil Regalia
    [644] = { { 27537, 28415, 28232, 27778, 27948 }, { 4, 2 } }, -- Oblivion Raiment
    [645] = { { 28963, 28968, 28966, 28967, 28964 }, { 2, 4, 2 } }, -- Voidheart Raiment
    [646] = { { 30211, 30212, 30213, 30215, 30214 }, { 2, 4 } }, -- Corruptor Raiment
    [647] = { { 28278, 27508, 27738, 28229, 27838 }, { 2, 4 } }, -- Incanter's Regalia
    [648] = { { 29076, 29080, 29078, 29079, 29077 }, { 4, 2 } }, -- Aldor Regalia
    [649] = { { 30206, 30205, 30207, 30210, 30196 }, { 4, 2 } }, -- Tirisfal Regalia
    [650] = { { 28228, 27474, 28275, 27874, 27801 }, { 4, 2 } }, -- Beast Lord Armor
    [651] = { { 29085, 29081, 29083, 29082, 29084 }, { 2, 4 } }, -- Demon Stalker Armor
    [652] = { { 30139, 30140, 30141, 30142, 30143 }, { 2, 4 } }, -- Rift Stalker Armor
    [653] = { { 28205, 27475, 27977, 27803, 28350 }, { 4, 2 } }, -- Bold Armor
    [654] = { { 29012, 29011, 29017, 29015, 29016 }, { 2, 4 } }, -- Warbringer Armor
    [655] = { { 29021, 29019, 29020, 29022, 29023 }, { 2, 4 } }, -- Warbringer Battlegear
    [656] = { { 30113, 30115, 30114, 30116, 30117 }, { 2, 4 } }, -- Destroyer Armor
    [657] = { { 30120, 30118, 30119, 30121, 30122 }, { 2, 4 } }, -- Destroyer Battlegear
    [658] = { { 28193, 27465, 27907, 28191, 27796 }, { 2, 4 } }, -- Mana-Etched Regalia
    [659] = { { 28264, 27531, 28224, 27837, 27797 }, { 4, 2 } }, -- Wastewalker Armor
    [660] = { { 27936, 28401, 27528, 28192, 27713 }, { 4, 2 } }, -- Desolation Battlegear
    [661] = { { 28403, 27497, 28225, 27870, 27771 }, { 4, 2 } }, -- Doomplate Battlegear
    [662] = { { 28413, 28230, 27536, 27775, 27875 }, { 2, 4 } }, -- Hallowed Raiment
    [663] = { { 29055, 29049, 29054, 29050, 29053 }, { 2, 4 } }, -- Incarnate Raiment
    [664] = { { 29057, 29059, 29056, 29058, 29060 }, { 2, 4 } }, -- Incarnate Regalia
    [665] = { { 30153, 30152, 30151, 30154, 30150 }, { 4, 2 } }, -- Avatar Raiment
    [666] = { { 30160, 30161, 30162, 30159, 30163 }, { 2, 4 } }, -- Avatar Regalia
    [667] = { { 31339, 31338 }, { 2 } }, -- The Twin Stars
    [668] = { { 31028, 31026, 31027, 31029, 31030, 34575, 34448, 34558 }, { 4, 2 } }, -- Slayer's Armor
    [669] = { { 31004, 31001, 31003, 31005, 31006, 34549, 34443, 34570 }, { 2, 4 } }, -- Gronnstalker's Armor
    [670] = { { 31050, 31051, 31053, 31054, 31052, 34564, 34436, 34541 }, { 2, 4 } }, -- Malefic Raiment
    [671] = { { 31056, 31055, 31058, 31059, 31057, 34574, 34447, 34557 }, { 2, 4 } }, -- Tempest Regalia
    [672] = { { 30972, 30975, 30969, 30977, 30979, 34546, 34441, 34569 }, { 2, 4 } }, -- Onslaught Battlegear
    [673] = { { 30976, 30974, 30970, 30978, 30980, 34568, 34442, 34547 }, { 4, 2 } }, -- Onslaught Armor
    [674] = { { 31061, 31064, 31067, 31070, 31065, 34434, 34528, 34563 }, { 2, 4 } }, -- Absolution Regalia
    [675] = { { 31068, 31063, 31060, 31069, 31066, 34562, 34527, 34435 }, { 4, 2 } }, -- Vestments of Absolution
    [676] = { { 31042, 31034, 31039, 31044, 31048, 34556, 34444, 34573 }, { 4, 2 } }, -- Thunderheart Harness
    [677] = { { 31043, 31035, 31040, 31046, 31049, 34572, 34446, 34555 }, { 2, 4 } }, -- Thunderheart Regalia
    [678] = { { 31041, 31032, 31037, 31045, 31047, 34571, 34445, 34554 }, { 2, 4 } }, -- Thunderheart Raiment
    [679] = { { 30991, 30987, 30985, 30995, 30998, 34488, 34433, 34560 }, { 2, 4 } }, -- Lightbringer Armor
    [680] = { { 30990, 30982, 30993, 30997, 30989, 34561, 34431, 34485 }, { 2, 4 } }, -- Lightbringer Battlegear
    [681] = { { 30992, 30983, 30988, 30994, 30996, 34432, 34487, 34559 }, { 4, 2 } }, -- Lightbringer Raiment
    [682] = { { 31018, 31011, 31015, 31021, 31024, 34567, 34439, 34545 }, { 2, 4 } }, -- Skyshatter Harness
    [683] = { { 31016, 31007, 31012, 31019, 31022, 34543, 34438, 34565 }, { 2, 4 } }, -- Skyshatter Raiment
    [684] = { { 31017, 31008, 31014, 31020, 31023, 34542, 34437, 34566 }, { 2, 4 } }, -- Skyshatter Regalia
    [685] = { { 31375, 31376, 31377, 31378, 31379 }, { 2, 4 } }, -- Gladiator's Refuge
    [686] = { { 31396, 31397, 31400, 31406, 31407 }, { 4, 2 } }, -- Gladiator's Wartide
    [687] = { { 31409, 31410, 31411, 31412, 31413 }, { 4, 2 } }, -- Gladiator's Investiture
    [688] = { { 31589, 31590, 31591, 31592, 31593 }, { 2, 4 } }, -- Grand Marshal's Refuge
    [689] = { { 31584, 31585, 31586, 31587, 31588 }, { 4, 2 } }, -- High Warlord's Refuge
    [690] = { { 31613, 31614, 31616, 31618, 31619 }, { 2, 4 } }, -- Gladiator's Redemption
    [691] = { { 31622, 31623, 31620, 31624, 31625 }, { 4, 2 } }, -- Grand Marshal's Investiture
    [692] = { { 31626, 31627, 31621, 31628, 31629 }, { 4, 2 } }, -- High Warlord's Investiture
    [693] = { { 31630, 31631, 31632, 31633, 31634 }, { 2, 4 } }, -- Grand Marshal's Redemption
    [694] = { { 31635, 31636, 31637, 31638, 31639 }, { 4, 2 } }, -- High Warlord's Redemption
    [695] = { { 31640, 31641, 31642, 31643, 31644 }, { 2, 4 } }, -- Grand Marshal's Wartide
    [696] = { { 31646, 31647, 31648, 31649, 31650 }, { 4, 2 } }, -- High Warlord's Wartide
    [697] = { { 29600, 29601, 29602, 29603, 29604, 29605 }, { 2, 3, 6 } }, -- Champion's Redoubt
    [698] = { { 29612, 29613, 29614, 29615, 29616, 29617 }, { 2, 3, 6 } }, -- Warlord's Aegis
    [699] = { { 32838, 32837 }, { 2, 2 } }, -- The Twin Blades of Azzinoth
    -- [700] = { { }, { 2, 4 } }, -- Merciless Gladiator's Aegis
    -- [701] = { { }, { 2, 4 } }, -- Merciless Gladiator's Battlegear
    -- [702] = { { }, { 2, 4 } }, -- Merciless Gladiator's Dreadgear
    -- [703] = { { }, { 2, 4 } }, -- Merciless Gladiator's Earthshaker
    -- [704] = { { }, { 2, 4 } }, -- Merciless Gladiator's Felshroud
    -- [705] = { { }, { 2, 4 } }, -- Merciless Gladiator's Investiture
    -- [706] = { { }, { 4, 2 } }, -- Merciless Gladiator's Pursuit
    -- [707] = { { }, { 2, 4 } }, -- Merciless Gladiator's Raiment
    -- [708] = { { }, { 4, 2 } }, -- Merciless Gladiator's Redemption
    -- [709] = { { }, { 2, 4 } }, -- Merciless Gladiator's Refuge
    -- [710] = { { }, { 4, 2 } }, -- Merciless Gladiator's Regalia
    -- [711] = { { }, { 2, 4 } }, -- Merciless Gladiator's Sanctuary
    -- [712] = { { }, { 4, 2 } }, -- Merciless Gladiator's Thunderfist
    -- [713] = { { }, { 2, 4 } }, -- Merciless Gladiator's Vestments
    -- [714] = { { }, { 4, 2 } }, -- Merciless Gladiator's Vindication
    -- [715] = { { }, { 2, 4 } }, -- Merciless Gladiator's Wartide
    -- [716] = { { }, { 4, 2 } }, -- Merciless Gladiator's Wildhide
    [717] = { { 29608, 29606, 29611, 29609, 29607, 29610 }, { 6, 2, 3 } }, -- Field Marshal's Earthshaker
    [718] = { { 29599, 29595, 29597, 29596, 29598, 29594 }, { 2, 6, 4 } }, -- Lieutenant Commander's Earthshaker
    [719] = { { 32946, 32945 }, { 2 } }, -- The Fists of Fury
    -- [720] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Refuge
    -- [721] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Sanctuary
    -- [722] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Wildhide
    -- [723] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Pursuit
    -- [724] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Regalia
    -- [725] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Redemption
    -- [726] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Vindication
    -- [727] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Aegis
    -- [728] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Investiture
    -- [729] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Raiment
    -- [730] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Vestments
    -- [731] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Wartide
    -- [732] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Earthshaker
    -- [733] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Thunderfist
    -- [734] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Dreadgear
    -- [735] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Felshroud
    -- [736] = { { }, { 2, 4 } }, -- Vengeful Gladiator's Battlegear
    [737] = { { 34703, 28189 }, { 2 } }, -- Latro's Flurry
    [738] = { { 35328, 35329, 35330, 35331, 35332 }, { 4, 2 } }, -- Dreadweave Battlegear
    [739] = { { 35333, 35334, 35335, 35336, 35337 }, { 4, 2 } }, -- Mooncloth Battlegear
    [740] = { { 35338, 35339, 35340, 35341, 35342 }, { 4, 2 } }, -- Satin Battlegear
    [741] = { { 35343, 35344, 35345, 35346, 35347 }, { 2, 4 } }, -- Evoker's Silk Battlegear
    [742] = { { 35356, 35357, 35358, 35360, 35359 }, { 4, 2 } }, -- Dragonhide Battlegear
    [743] = { { 35371, 35372, 35373, 35375, 35374 }, { 4, 2 } }, -- Wyrmhide Battlegear
    [744] = { { 35361, 35362, 35363, 35365, 35364 }, { 4, 2 } }, -- Kodohide Battlegear
    [745] = { { 35366, 35367, 35368, 35369, 35370 }, { 4, 2 } }, -- Opportunist's Battlegear
    [746] = { { 35386, 35387, 35388, 35389, 35390 }, { 4, 2 } }, -- Seer's Mail Battlegear
    [747] = { { 35391, 35392, 35393, 35394, 35395 }, { 4, 2 } }, -- Seer's Ringmail Battlegear
    [748] = { { 35381, 35382, 35383, 35384, 35385 }, { 4, 2 } }, -- Seer's Linked Battlegear
    [749] = { { 35376, 35377, 35378, 35379, 35380 }, { 2, 4 } }, -- Stalker's Chain Battlegear
    [750] = { { 35407, 35408, 35409, 35410, 35411 }, { 4, 2 } }, -- Savage Plate Battlegear
    [751] = { { 35402, 35403, 35404, 35405, 35406 }, { 2, 4 } }, -- Crusader's Ornamented Battlegear
    [752] = { { 35412, 35413, 35414, 35415, 35416 }, { 4, 2 } }, -- Crusader's Scaled Battlegear
    [754] = { { 38405, 38404, 38400, 38403, 38401, 38402, 38437, 38433 }, { 2, 4 } }, -- Borean Embrace
    [755] = { { 38418, 38419, 38420, 38421, 38422, 38417, 38439, 38435 }, { 2, 4 } }, -- Nerubian Hive
    [756] = { { 38412, 38413, 38414, 38415, 38416, 38424, 38436, 38440 }, { 2, 4 } }, -- Frostscale Binding
    [757] = { { 38406, 38407, 38408, 38409, 38410, 38411, 38434, 38438 }, { 3 } }, -- Iceborne Embrace
    [759] = { { 37758, 37821 }, { 2 } }, -- Raine's Revenge
    [760] = { { 40440, 40441, 40442, 40443, 40444 }, { 2 } }, -- Gladiator's Dreadplate
    [761] = { { 34087, 21525, 34085, 21524, 34086 }, { 3 } }, -- Winter Garb
    [762] = { { 33862, 33863, 33868, 33966, 33969, 33967, 33864, 33968 }, { 3 } }, -- Brewfest Garb
    [763] = { { 41522, 41520, 44211, 41521, 41519, 41515, 41513, 41512 }, { 4, 2 } }, -- Frostwoven Power
    [764] = { { 41543, 41544, 41545, 41546, 41548, 41549, 41550, 41551 }, { 2, 4 } }, -- Duskweaver
    [765] = { { 42625, 42626, 42627, 42628, 42629 }, { 4, 2, 2, 4 } }, -- Gladiator's Battlegear
    [766] = { { 42630, 42631, 42632, 42633, 42634 }, { 2, 4, 2, 4 } }, -- Gladiator's Vindication
    [767] = { { 42635, 42636, 42637, 42638, 42639 }, { 4, 2, 2, 4 } }, -- Gladiator's Redemption
    [768] = { { 42654, 42655, 42656, 42657, 42658 }, { 2, 4, 2, 4 } }, -- Gladiator's Desecration
    [769] = { { 42659, 42660, 42661, 42662, 42663 }, { 2, 4, 2, 4 } }, -- Gladiator's Thunderfist
    [770] = { { 42669, 42670, 42671, 42672, 42673 }, { 2, 4, 2, 4 } }, -- Gladiator's Earthshaker
    [771] = { { 42664, 42665, 42666, 42667, 42668 }, { 2, 4, 4, 2 } }, -- Gladiator's Wartide
    [772] = { { 42674, 42675, 42676, 42677, 42678 }, { 4, 2, 2, 4 } }, -- Gladiator's Pursuit
    [773] = { { 42680, 42681, 42682, 42683, 42684 }, { 2, 4, 2, 4 } }, -- Gladiator's Refuge
    [774] = { { 42685, 42686, 42687, 42688, 42689 }, { 2, 4, 2, 4 } }, -- Gladiator's Wildhide
    [775] = { { 42690, 42691, 42692, 42693, 42694 }, { 2, 4, 2, 4 } }, -- Gladiator's Sanctuary
    [776] = { { 42695, 42696, 42697, 42698, 42699 }, { 4, 2, 2, 4 } }, -- Gladiator's Vestments
    [777] = { { 42703, 42704, 42705, 42706, 42707 }, { 2, 4, 2, 4 } }, -- Gladiator's Investiture
    [778] = { { 42708, 42709, 42710, 42711, 42712 }, { 4, 2, 2, 4 } }, -- Gladiator's Raiment
    [779] = { { 42713, 42714, 42715, 42716, 42717 }, { 2, 4, 2, 4 } }, -- Gladiator's Regalia
    [780] = { { 42718, 42719, 42720, 42721, 42722 }, { 4, 2, 2, 4 } }, -- Gladiator's Felshroud
    [781] = { { 43073, 43074, 43075, 43072 }, { 2, 3, 4 } }, -- Blessed Regalia of Undead Cleansing
    [782] = { { 43078, 43077, 43079, 43076 }, { 2, 3, 4 } }, -- Undead Slayer's Blessed Armor
    [783] = { { 43082, 43081, 43083, 43080 }, { 2, 3, 4 } }, -- Blessed Garb of the Undead Slayer
    [784] = { { 43070, 43068, 43071, 43069 }, { 2, 3, 4 } }, -- Blessed Battlegear of Undead Slaying
    [785] = { { 23324, 34685, 34683 }, { 3 } }, -- Midsummer Reveler
    [787] = { { 43740, 43742, 43743, 43745, 43747 }, { 2, 4 } }, -- Dreadnaught Plate
    [788] = { { 43739, 43744, 43746, 43741, 43748 }, { 2, 4 } }, -- Dreadnaught Battlegear
    [789] = { { 43794, 43796, 43801, 43803, 43805 }, { 2, 4 } }, -- Redemption Battlegear
    [790] = { { 43797, 43798, 43800, 43806, 43807 }, { 2, 4 } }, -- Redemption Regalia
    [791] = { { 43793, 43795, 43799, 43802, 43804 }, { 2, 4 } }, -- Redemption Plate
    [792] = { { 43809, 43813, 43815, 43817, 43819 }, { 2, 4 } }, -- Scourgeborne Battlegear
    [793] = { { 43811, 43812, 43814, 43816, 43818 }, { 2, 4 } }, -- Scourgeborne Plate
    [794] = { { 43734, 43735, 43736, 43737, 43738 }, { 2, 4 } }, -- Cryptstalker Battlegear
    [795] = { { 43762, 43763, 43765, 43772, 43776 }, { 2, 4 } }, -- Earthshatter Battlegear
    [796] = { { 43764, 43767, 43769, 43770, 43773 }, { 2, 4 } }, -- Earthshatter Garb
    [797] = { { 43766, 43768, 43771, 43774, 43775 }, { 2, 4 } }, -- Earthshatter Regalia
    [798] = { { 43751, 43753, 43756, 43822, 43758 }, { 2, 4 } }, -- Dreamwalker Battlegear
    [799] = { { 43752, 43754, 43755, 43759, 43820 }, { 2, 4 } }, -- Dreamwalker Regalia
    [800] = { { 43749, 43750, 43757, 43760, 43761 }, { 2, 4 } }, -- Dreamwalker Garb
    [801] = { { 43727, 43728, 43729, 43730, 43731 }, { 2, 4 } }, -- Bonescythe Battlegear
    [802] = { { 43787, 43788, 43789, 43790, 43791 }, { 2, 4 } }, -- Plagueheart Garb
    [803] = { { 43777, 43778, 43779, 43780, 43781 }, { 2, 4 } }, -- Frostfire Garb
    [804] = { { 43733, 43782, 43784, 43808, 43810 }, { 2, 4 } }, -- Regalia of Faith
    [805] = { { 43732, 43783, 43785, 43786, 43792 }, { 2, 4 } }, -- Garb of Faith
    [812] = { { 6835, 6833 }, { 2 } }, -- Spring Tuxedo
    [813] = { { 43435, 43434, 43260, 43436, 43438, 43433, 43439, 43437 }, { 6, 4 } }, -- Eviscerator's Battlegear
    [814] = { { 42723, 42724, 42725, 42726, 42727, 42728, 42730, 42729 }, { 4, 6 } }, -- Ornate Saronite Battlegear
    [815] = { { 43266, 43273, 43264, 43263, 43265, 43261, 43271, 43262 }, { 6, 4 } }, -- Overcaster Battlegear
    [816] = { { 41354, 41349, 41353, 41347, 41351, 41350, 41352, 41348 }, { 4, 6 } }, -- Savage Saronite Battlegear
    [817] = { { 43450, 43455, 43454, 43453, 43456, 43457, 43451, 43452 }, { 6, 4 } }, -- Stormhide Battlegear
    [818] = { { 43442, 43443, 43444, 43446, 43445, 43447, 43448, 43449 }, { 4, 6 } }, -- Swiftarrow Battlegear
    [819] = { { 43969, 43970, 43974, 43971, 41516, 43975, 43972, 43973 }, { 6, 4 } }, -- Frostsavage Battlegear
    [820] = { { 46213, 46216, 46221, 46224, 46226 }, { 2, 4 } }, -- Aegis Battlegear
    [821] = { { 46214, 46215, 46219, 46222, 46225 }, { 2, 4 } }, -- Aegis Plate
    [822] = { { 46217, 46218, 46220, 46227, 46228 }, { 2, 4 } }, -- Aegis Regalia
    [823] = { { 46293, 46294, 46296, 46303, 46307 }, { 2, 4 } }, -- Worldbreaker Battlegear
    [824] = { { 46295, 46298, 46300, 46301, 46304 }, { 4, 2 } }, -- Worldbreaker Garb
    [825] = { { 46297, 46299, 46302, 46305, 46306 }, { 2, 4 } }, -- Worldbreaker Regalia
    [826] = { { 46288, 46289, 46290, 46291, 46292 }, { 2, 4 } }, -- Terrorblade Battlegear
    [827] = { { 46260, 46262, 46265, 46267, 46269 }, { 2, 4 } }, -- Nightsong Battlegear
    [828] = { { 45350, 46309, 46266, 46271, 46272 }, { 2, 4 } }, -- Nightsong Garb
    [829] = { { 46261, 46263, 46264, 46268, 46270 }, { 2, 4 } }, -- Nightsong Regalia
    [830] = { { 46278, 46280, 46282, 46285, 46287 }, { 2, 4 } }, -- Siegebreaker Battlegear
    [831] = { { 46279, 46281, 46283, 46284, 46286 }, { 2, 4 } }, -- Siegebreaker Plate
    [832] = { { 46230, 46248, 46255, 46256, 46257 }, { 2, 4 } }, -- Sanctification Garb
    [833] = { { 46231, 46247, 46254, 46258, 46259 }, { 2, 4 } }, -- Sanctification Regalia
    [834] = { { 46232, 46235, 46237, 46239, 46241 }, { 2, 4 } }, -- Darkruned Battlegear
    [835] = { { 46233, 46234, 46236, 46238, 46240 }, { 2, 4 } }, -- Darkruned Plate
    [836] = { { 46249, 46250, 46251, 46252, 46253 }, { 2, 4 } }, -- Kirin Tor Garb
    [837] = { { 46242, 46243, 46244, 46245, 46246 }, { 2, 4 } }, -- Deathbringer Garb
    [838] = { { 46273, 46274, 46275, 46276, 46277 }, { 2, 4 } }, -- Scourgestalker Battlegear
    [843] = { { 48725, 48726, 48727, 48728, 48729 }, { 2, 4 } }, -- Khadgar's Regalia
    [844] = { { 48730, 48731, 48732, 48733, 48734 }, { 2, 4 } }, -- Sunstrider's Regalia
    [845] = { { 48735, 48736, 48737, 48738, 48739 }, { 2, 4 } }, -- Gul'dan's Regalia
    [846] = { { 48740, 48741, 48742, 48743, 48744 }, { 2, 4 } }, -- Kel'Thuzad's Regalia
    [847] = { { 48745, 48746, 48747, 48748, 48749 }, { 2, 4 } }, -- Velen's Raiment
    [848] = { { 48750, 48751, 48752, 48753, 48754 }, { 2, 4 } }, -- Zabra's Raiment
    [849] = { { 48755, 48756, 48757, 48758, 48759 }, { 2, 4 } }, -- Velen's Regalia
    [850] = { { 48760, 48761, 48762, 48763, 48764 }, { 2, 4 } }, -- Zabra's Regalia
    [851] = { { 48774, 48775, 48776, 48777, 48778 }, { 2, 4 } }, -- Malfurion's Garb
    [852] = { { 48769, 48770, 48771, 48772, 48773 }, { 2, 4 } }, -- Runetotem's Garb
    [853] = { { 48786, 48787, 48788, 48789, 48790 }, { 2, 4 } }, -- Malfurion's Regalia
    [854] = { { 48781, 48782, 48783, 48784, 48785 }, { 2, 4 } }, -- Runetotem's Regalia
    [855] = { { 48799, 48800, 48801, 48802, 48803 }, { 2, 4 } }, -- Malfurion's Battlegear
    [856] = { { 48794, 48795, 48796, 48797, 48798 }, { 2, 4 } }, -- Runetotem's Battlegear
    [857] = { { 48809, 48810, 48811, 48812, 48813 }, { 2, 4 } }, -- VanCleef's Battlegear
    [858] = { { 48804, 48805, 48806, 48807, 48808 }, { 4, 2 } }, -- Garona's Battlegear
    [859] = { { 48819, 48820, 48821, 48822, 48823 }, { 2, 4 } }, -- Windrunner's Battlegear
    [860] = { { 48814, 48815, 48816, 48817, 48818 }, { 4, 2 } }, -- Windrunner's Pursuit
    [861] = { { 48824, 48825, 48826, 48827, 48828 }, { 2, 4 } }, -- Nobundo's Garb
    [862] = { { 48829, 48830, 48831, 48832, 48833 }, { 2, 4 } }, -- Thrall's Garb
    [863] = { { 48841, 48842, 48843, 48844, 48845 }, { 2, 4 } }, -- Thrall's Regalia
    [864] = { { 48836, 48837, 48838, 48839, 48840 }, { 4, 2 } }, -- Nobundo's Regalia
    [865] = { { 48846, 48847, 48848, 48849, 48850 }, { 2, 4 } }, -- Nobundo's Battlegear
    [866] = { { 48854, 48855, 48852, 48853, 48851 }, { 2, 4 } }, -- Thrall's Battlegear
    [867] = { { 48865, 48866, 48867, 48868, 48869 }, { 2, 4 } }, -- Wrynn's Battlegear
    [868] = { { 48860, 48861, 48862, 48863, 48864 }, { 2, 4 } }, -- Hellscream's Battlegear
    [869] = { { 48875, 48876, 48877, 48878, 48879 }, { 2, 4 } }, -- Wrynn's Plate
    [870] = { { 48870, 48871, 48872, 48873, 48874 }, { 2, 4 } }, -- Hellscream's Plate
    [871] = { { 48885, 48886, 48887, 48888, 48889 }, { 4, 2 } }, -- Thassarian's Battlegear
    [872] = { { 48880, 48881, 48882, 48883, 48884 }, { 2, 4 } }, -- Koltira's Battlegear
    [873] = { { 48895, 48896, 48897, 48898, 48899 }, { 4, 2 } }, -- Thassarian's Plate
    [874] = { { 48890, 48891, 48892, 48893, 48894 }, { 2, 4 } }, -- Koltira's Plate
    [875] = { { 48904, 48903, 48902, 48901, 48900 }, { 2, 4 } }, -- Turalyon's Garb
    [876] = { { 48909, 48908, 48907, 48906, 48905 }, { 2, 4 } }, -- Liadrin's Garb
    [877] = { { 48915, 48916, 48917, 48918, 48919 }, { 2, 4 } }, -- Turalyon's Battlegear
    [878] = { { 48910, 48911, 48912, 48913, 48914 }, { 4, 2 } }, -- Liadrin's Battlegear
    [879] = { { 48927, 48928, 48929, 48930, 48931 }, { 2, 4 } }, -- Turalyon's Plate
    [880] = { { 48922, 48923, 48924, 48925, 48926 }, { 4, 2 } }, -- Liadrin's Plate
    [881] = { { 49310, 49463 }, { 2, 2 } }, -- Purified Shard of the Gods
    [882] = { { 49488, 49464 }, { 2, 2 } }, -- Shiny Shard of the Gods
    [883] = { { 51716, 51715, 51714, 51713, 51712 }, { 4, 2 } }, -- Bloodmage's Regalia
    [884] = { { 51766, 51765, 51764, 51763, 51762 }, { 4, 2 } }, -- Dark Coven's Regalia
    [885] = { { 51732, 51733, 51734, 51735, 51736 }, { 4, 2 } }, -- Crimson Acolyte's Raiment
    [886] = { { 51741, 51740, 51739, 51738, 51737 }, { 4, 2 } }, -- Crimson Acolyte's Regalia
    [887] = { { 51696, 51695, 51694, 51693, 51692 }, { 4, 2 } }, -- Lasherweave Garb
    [888] = { { 51706, 51705, 51704, 51703, 51702 }, { 4, 2 } }, -- Lasherweave Regalia
    [889] = { { 51701, 51700, 51699, 51698, 51697 }, { 4, 2 } }, -- Lasherweave Battlegear
    [890] = { { 51746, 51745, 51744, 51743, 51742 }, { 4, 2 } }, -- Shadowblade's Battlegear
    [891] = { { 51711, 51710, 51709, 51708, 51707 }, { 2, 4 } }, -- Ahn'Kahar Blood Hunter's Battlegear
    [892] = { { 51747, 51748, 51749, 51750, 51751 }, { 4, 2 } }, -- Frost Witch's Garb
    [893] = { { 51757, 51758, 51759, 51760, 51761 }, { 4, 2 } }, -- Frost Witch's Regalia
    [894] = { { 51752, 51753, 51754, 51755, 51756 }, { 4, 2 } }, -- Frost Witch's Battlegear
    [895] = { { 51771, 51770, 51769, 51768, 51767 }, { 4, 2 } }, -- Ymirjar Lord's Battlegear
    [896] = { { 51776, 51775, 51774, 51773, 51772 }, { 4, 2 } }, -- Ymirjar Lord's Plate
    [897] = { { 51686, 51685, 51684, 51683, 51682 }, { 2, 4 } }, -- Scourgelord's Battlegear
    [898] = { { 51691, 51690, 51689, 51688, 51687 }, { 4, 2 } }, -- Scourgelord's Plate
    [899] = { { 51726, 51725, 51724, 51723, 51722 }, { 4, 2 } }, -- Lightsworn Garb
    [900] = { { 51721, 51720, 51719, 51718, 51717 }, { 4, 2 } }, -- Lightsworn Battlegear
    [901] = { { 51731, 51730, 51729, 51728, 51727 }, { 4, 2 } }, -- Lightsworn Plate
};

for id, set in pairs(ezCollections.ItemSet) do
    table.sort(set[2]);
end

ezCollections.ItemXItemSet =
{
    [6473] = 162, [6833] = 812, [6835] = 812, [7948] = 221, [7949] = 221, [7950] = 221, [7951] = 221, [7952] = 221, [7953] = 221, [10328] = 163, [10329] = 163, [10330] = 163, [10331] = 163, [10332] = 163, [10333] = 163, [10399] = 161, [10400] = 161, [10401] = 161, [10402] = 161, [10403] = 161, [10410] = 162, [10411] = 162, [10412] = 162, [10413] = 162, [11726] = 1, [11728] = 1, [11729] = 1, [11730] = 1, [11731] = 1, [12422] = 321, [12424] = 321, [12425] = 321, [12426] = 321, [12427] = 321, [12428] = 321, [12429] = 321, [12939] = 41, [12940] = 41, [13183] = 65, [13218] = 65, [13388] = 81, [13389] = 81, [13390] = 81, [13391] = 81, [13392] = 81, [14611] = 123, [14612] = 123, [14614] = 123, [14615] = 123, [14616] = 123, [14620] = 124, [14621] = 124, [14622] = 124, [14623] = 124, [14624] = 124, [14626] = 122, [14629] = 122, [14631] = 122, [14632] = 122, [14633] = 122, [14636] = 121, [14637] = 121, [14638] = 121, [14640] = 121, [14641] = 121, [15045] = 490, [15046] = 490, [15048] = 491, [15049] = 491, [15050] = 489, [15051] = 489, [15052] = 489, [15053] = 141, [15054] = 141, [15055] = 141, [15056] = 142, [15057] = 142, [15058] = 142, [15062] = 143, [15063] = 143, [15066] = 144, [15067] = 144, [16369] = 343, [16391] = 343, [16392] = 348, [16393] = 381, [16396] = 348, [16397] = 381, [16401] = 362, [16403] = 362, [16405] = 282, [16406] = 282, [16409] = 401, [16410] = 401, [16413] = 343, [16414] = 343, [16415] = 343, [16416] = 343, [16417] = 348, [16418] = 348, [16419] = 348, [16420] = 348, [16421] = 381, [16422] = 381, [16423] = 381, [16424] = 381, [16425] = 362, [16426] = 362, [16427] = 362, [16428] = 362, [16429] = 282, [16430] = 282, [16431] = 282, [16432] = 282, [16433] = 401, [16434] = 401, [16435] = 401, [16436] = 401, [16437] = 388, [16440] = 388, [16441] = 388, [16442] = 388, [16443] = 388, [16444] = 388, [16446] = 394, [16448] = 397, [16449] = 397, [16450] = 397, [16451] = 397, [16452] = 397, [16453] = 394, [16454] = 394, [16455] = 394, [16456] = 394, [16457] = 394, [16459] = 397, [16462] = 395, [16463] = 395, [16465] = 395, [16466] = 395, [16467] = 395, [16468] = 395, [16471] = 402, [16472] = 402, [16473] = 402, [16474] = 402, [16475] = 402, [16476] = 402, [16477] = 384, [16478] = 384, [16479] = 384, [16480] = 384, [16483] = 384, [16484] = 384, [16485] = 341, [16487] = 341, [16489] = 341, [16490] = 341, [16491] = 341, [16492] = 341, [16494] = 382, [16496] = 382, [16498] = 347, [16499] = 347, [16501] = 382, [16502] = 382, [16503] = 382, [16504] = 382, [16505] = 347, [16506] = 347, [16507] = 347, [16508] = 347, [16509] = 281, [16510] = 281, [16513] = 281, [16514] = 281, [16515] = 281, [16516] = 281, [16518] = 301, [16519] = 301, [16521] = 301, [16522] = 301, [16523] = 301, [16524] = 301, [16525] = 361, [16526] = 361, [16527] = 361, [16528] = 361, [16530] = 361, [16531] = 361, [16533] = 387, [16534] = 387, [16535] = 387, [16536] = 387, [16539] = 387, [16540] = 387, [16541] = 383, [16542] = 383, [16543] = 383, [16544] = 383, [16545] = 383, [16548] = 383, [16549] = 398, [16550] = 398, [16551] = 398, [16552] = 398, [16554] = 398, [16555] = 398, [16558] = 393, [16560] = 393, [16561] = 393, [16562] = 393, [16563] = 393, [16564] = 393, [16565] = 396, [16566] = 396, [16567] = 396, [16568] = 396, [16569] = 396, [16571] = 396, [16573] = 386, [16574] = 386, [16577] = 386, [16578] = 386, [16579] = 386, [16580] = 386, [16666] = 187, [16667] = 187, [16668] = 187, [16669] = 187, [16670] = 187, [16671] = 187, [16672] = 187, [16673] = 187, [16674] = 186, [16675] = 186, [16676] = 186, [16677] = 186, [16678] = 186, [16679] = 186, [16680] = 186, [16681] = 186, [16682] = 181, [16683] = 181, [16684] = 181, [16685] = 181, [16686] = 181, [16687] = 181, [16688] = 181, [16689] = 181, [16690] = 182, [16691] = 182, [16692] = 182, [16693] = 182, [16694] = 182, [16695] = 182, [16696] = 182, [16697] = 182, [16698] = 183, [16699] = 183, [16700] = 183, [16701] = 183, [16702] = 183, [16703] = 183, [16704] = 183, [16705] = 183, [16706] = 185, [16707] = 184, [16708] = 184, [16709] = 184, [16710] = 184, [16711] = 184, [16712] = 184, [16713] = 184, [16714] = 185, [16715] = 185, [16716] = 185, [16717] = 185, [16718] = 185, [16719] = 185, [16720] = 185, [16721] = 184, [16722] = 188, [16723] = 188, [16724] = 188, [16725] = 188, [16726] = 188, [16727] = 188, [16728] = 188, [16729] = 188, [16730] = 189, [16731] = 189, [16732] = 189, [16733] = 189, [16734] = 189, [16735] = 189, [16736] = 189, [16737] = 189, [16795] = 201, [16796] = 201, [16797] = 201, [16798] = 201, [16799] = 201, [16800] = 201, [16801] = 201, [16802] = 201, [16803] = 203, [16804] = 203, [16805] = 203, [16806] = 203, [16807] = 203, [16808] = 203, [16809] = 203, [16810] = 203, [16811] = 202, [16812] = 202, [16813] = 202, [16814] = 202, [16815] = 202, [16816] = 202, [16817] = 202, [16818] = 210, [16819] = 202, [16820] = 204, [16821] = 204, [16822] = 204, [16823] = 204, [16824] = 204, [16825] = 204, [16826] = 204, [16827] = 204, [16828] = 205, [16829] = 205, [16830] = 205, [16831] = 205, [16832] = 213, [16833] = 205, [16834] = 205, [16835] = 205, [16836] = 205, [16837] = 207, [16838] = 207, [16839] = 207, [16840] = 207, [16841] = 207, [16842] = 207, [16843] = 207, [16844] = 207, [16845] = 206, [16846] = 206, [16847] = 206, [16848] = 206, [16849] = 206, [16850] = 206, [16851] = 206, [16852] = 206, [16853] = 208, [16854] = 208, [16855] = 208, [16856] = 208, [16857] = 208, [16858] = 208, [16859] = 208, [16860] = 208, [16861] = 209, [16862] = 209, [16863] = 209, [16864] = 209, [16865] = 209, [16866] = 209, [16867] = 209, [16868] = 209, [16897] = 214, [16898] = 214, [16899] = 214, [16900] = 214, [16901] = 214, [16902] = 214, [16903] = 214, [16904] = 214, [16905] = 213, [16906] = 213, [16907] = 213, [16908] = 213, [16909] = 213, [16910] = 213, [16911] = 213, [16912] = 210, [16913] = 210, [16914] = 210, [16915] = 210, [16916] = 210, [16917] = 210, [16918] = 210, [16919] = 211, [16920] = 211, [16921] = 211, [16922] = 211, [16923] = 211, [16924] = 211, [16925] = 211, [16926] = 211, [16927] = 212, [16928] = 212, [16929] = 212, [16930] = 212, [16931] = 212, [16932] = 212, [16933] = 212, [16934] = 212, [16935] = 215, [16936] = 215, [16937] = 215, [16938] = 215, [16939] = 215, [16940] = 215, [16941] = 215, [16942] = 215, [16943] = 216, [16944] = 216, [16945] = 216, [16946] = 216, [16947] = 216, [16948] = 216, [16949] = 216, [16950] = 216, [16951] = 217, [16952] = 217, [16953] = 217, [16954] = 217, [16955] = 217, [16956] = 217, [16957] = 217, [16958] = 217, [16959] = 218, [16960] = 218, [16961] = 218, [16962] = 218, [16963] = 218, [16964] = 218, [16965] = 218, [16966] = 218, [16984] = 489, [17064] = 241, [17082] = 241, [17562] = 346, [17564] = 346, [17566] = 346, [17567] = 346, [17568] = 346, [17569] = 346, [17570] = 345, [17571] = 345, [17572] = 345, [17573] = 345, [17576] = 345, [17577] = 345, [17578] = 392, [17579] = 392, [17580] = 392, [17581] = 392, [17583] = 392, [17584] = 392, [17586] = 391, [17588] = 391, [17590] = 391, [17591] = 391, [17592] = 391, [17593] = 391, [17594] = 344, [17596] = 344, [17598] = 344, [17599] = 344, [17600] = 344, [17601] = 344, [17602] = 389, [17603] = 389, [17604] = 389, [17605] = 389, [17607] = 389, [17608] = 389, [17610] = 342, [17611] = 342, [17612] = 342, [17613] = 342, [17616] = 342, [17617] = 342, [17618] = 390, [17620] = 390, [17622] = 390, [17623] = 390, [17624] = 390, [17625] = 390, [18202] = 261, [18203] = 261, [19577] = 474, [19588] = 475, [19594] = 480, [19601] = 482, [19605] = 481, [19609] = 476, [19613] = 479, [19617] = 478, [19621] = 477, [19682] = 421, [19683] = 421, [19684] = 421, [19685] = 441, [19686] = 441, [19687] = 441, [19688] = 442, [19689] = 442, [19690] = 443, [19691] = 443, [19692] = 443, [19693] = 444, [19694] = 444, [19695] = 444, [19822] = 474, [19823] = 474, [19824] = 474, [19825] = 475, [19826] = 475, [19827] = 475, [19828] = 476, [19829] = 476, [19830] = 476, [19831] = 477, [19832] = 477, [19833] = 477, [19834] = 478, [19835] = 478, [19836] = 478, [19838] = 479, [19839] = 479, [19840] = 479, [19841] = 480, [19842] = 480, [19843] = 480, [19845] = 482, [19846] = 482, [19848] = 481, [19849] = 481, [19863] = 465, [19865] = 461, [19866] = 461, [19873] = 464, [19893] = 462, [19896] = 463, [19898] = 466, [19905] = 462, [19910] = 463, [19912] = 464, [19920] = 465, [19925] = 466, [19951] = 474, [19952] = 475, [19953] = 477, [19954] = 478, [19955] = 479, [19956] = 476, [19957] = 481, [19958] = 480, [19959] = 482, [20033] = 481, [20034] = 482, [20041] = 467, [20042] = 468, [20043] = 469, [20044] = 470, [20045] = 471, [20046] = 472, [20047] = 473, [20048] = 467, [20049] = 468, [20050] = 469, [20051] = 470, [20052] = 471, [20053] = 472, [20054] = 473, [20055] = 469, [20056] = 470, [20057] = 467, [20058] = 468, [20059] = 471, [20060] = 472, [20061] = 473, [20150] = 483, [20154] = 483, [20158] = 483, [20159] = 485, [20163] = 485, [20167] = 488, [20171] = 488, [20175] = 488, [20176] = 485, [20186] = 486, [20190] = 486, [20194] = 486, [20195] = 484, [20199] = 484, [20203] = 484, [20204] = 487, [20208] = 487, [20212] = 487, [20295] = 491, [20296] = 490, [20406] = 492, [20407] = 492, [20408] = 492, [21278] = 142, [21329] = 496, [21330] = 496, [21331] = 496, [21332] = 496, [21333] = 496, [21334] = 499, [21335] = 499, [21336] = 499, [21337] = 499, [21338] = 499, [21343] = 503, [21344] = 503, [21345] = 503, [21346] = 503, [21347] = 503, [21348] = 507, [21349] = 507, [21350] = 507, [21351] = 507, [21352] = 507, [21353] = 493, [21354] = 493, [21355] = 493, [21356] = 493, [21357] = 493, [21359] = 497, [21360] = 497, [21361] = 497, [21362] = 497, [21364] = 497, [21365] = 509, [21366] = 509, [21367] = 509, [21368] = 509, [21370] = 509, [21372] = 501, [21373] = 501, [21374] = 501, [21375] = 501, [21376] = 501, [21387] = 505, [21388] = 505, [21389] = 505, [21390] = 505, [21391] = 505, [21392] = 495, [21393] = 495, [21394] = 495, [21395] = 506, [21396] = 506, [21397] = 506, [21398] = 502, [21399] = 502, [21400] = 502, [21401] = 510, [21402] = 510, [21403] = 510, [21404] = 498, [21405] = 498, [21406] = 498, [21407] = 494, [21408] = 494, [21409] = 494, [21410] = 508, [21411] = 508, [21412] = 508, [21413] = 504, [21414] = 504, [21415] = 504, [21416] = 500, [21417] = 500, [21418] = 500, [21524] = 761, [21525] = 761, [21846] = 552, [21847] = 552, [21848] = 552, [21849] = 555, [21850] = 555, [21851] = 555, [21852] = 555, [21853] = 555, [21854] = 555, [21855] = 555, [21859] = 556, [21860] = 556, [21861] = 556, [21862] = 556, [21863] = 557, [21864] = 557, [21865] = 557, [21866] = 558, [21867] = 558, [21868] = 558, [21869] = 553, [21870] = 553, [21871] = 553, [21873] = 554, [21874] = 554, [21875] = 554, [21994] = 511, [21995] = 511, [21996] = 511, [21997] = 511, [21998] = 511, [21999] = 511, [22000] = 511, [22001] = 511, [22002] = 512, [22003] = 512, [22004] = 512, [22005] = 512, [22006] = 512, [22007] = 512, [22008] = 512, [22009] = 512, [22010] = 515, [22011] = 515, [22013] = 515, [22015] = 515, [22016] = 515, [22017] = 515, [22060] = 515, [22061] = 515, [22062] = 517, [22063] = 517, [22064] = 517, [22065] = 517, [22066] = 517, [22067] = 517, [22068] = 517, [22069] = 517, [22070] = 518, [22071] = 518, [22072] = 518, [22073] = 518, [22074] = 518, [22075] = 518, [22076] = 518, [22077] = 518, [22078] = 514, [22079] = 514, [22080] = 514, [22081] = 514, [22082] = 514, [22083] = 514, [22084] = 514, [22085] = 514, [22086] = 516, [22087] = 516, [22088] = 516, [22089] = 516, [22090] = 516, [22091] = 516, [22092] = 516, [22093] = 516, [22095] = 519, [22096] = 519, [22097] = 519, [22098] = 519, [22099] = 519, [22100] = 519, [22101] = 519, [22102] = 519, [22106] = 513, [22107] = 513, [22108] = 513, [22109] = 513, [22110] = 513, [22111] = 513, [22112] = 513, [22113] = 513, [22301] = 520, [22302] = 520, [22303] = 520, [22304] = 520, [22305] = 520, [22306] = 520, [22311] = 520, [22313] = 520, [22416] = 523, [22417] = 523, [22418] = 523, [22419] = 523, [22420] = 523, [22421] = 523, [22422] = 523, [22423] = 523, [22424] = 528, [22425] = 528, [22426] = 528, [22427] = 528, [22428] = 528, [22429] = 528, [22430] = 528, [22431] = 528, [22436] = 530, [22437] = 530, [22438] = 530, [22439] = 530, [22440] = 530, [22441] = 530, [22442] = 530, [22443] = 530, [22464] = 527, [22465] = 527, [22466] = 527, [22467] = 527, [22468] = 527, [22469] = 527, [22470] = 527, [22471] = 527, [22476] = 524, [22477] = 524, [22478] = 524, [22479] = 524, [22480] = 524, [22481] = 524, [22482] = 524, [22483] = 524, [22488] = 521, [22489] = 521, [22490] = 521, [22491] = 521, [22492] = 521, [22493] = 521, [22494] = 521, [22495] = 521, [22496] = 526, [22497] = 526, [22498] = 526, [22499] = 526, [22500] = 526, [22501] = 526, [22502] = 526, [22503] = 526, [22504] = 529, [22505] = 529, [22506] = 529, [22507] = 529, [22508] = 529, [22509] = 529, [22510] = 529, [22511] = 529, [22512] = 525, [22513] = 525, [22514] = 525, [22515] = 525, [22516] = 525, [22517] = 525, [22518] = 525, [22519] = 525, [22843] = 543, [22852] = 539, [22855] = 541, [22856] = 522, [22857] = 538, [22858] = 537, [22859] = 540, [22860] = 542, [22862] = 543, [22863] = 539, [22864] = 522, [22865] = 541, [22867] = 538, [22868] = 537, [22869] = 540, [22870] = 542, [22872] = 537, [22873] = 537, [22874] = 543, [22875] = 543, [22876] = 538, [22877] = 539, [22878] = 539, [22879] = 522, [22880] = 522, [22881] = 541, [22882] = 540, [22883] = 542, [22884] = 541, [22885] = 540, [22886] = 542, [22887] = 538, [23059] = 523, [23060] = 524, [23061] = 525, [23062] = 526, [23063] = 529, [23064] = 521, [23065] = 527, [23066] = 528, [23067] = 530, [23078] = 533, [23081] = 534, [23082] = 535, [23084] = 536, [23085] = 536, [23087] = 533, [23088] = 535, [23089] = 534, [23090] = 533, [23091] = 536, [23092] = 535, [23093] = 534, [23243] = 537, [23244] = 537, [23251] = 543, [23252] = 543, [23253] = 539, [23254] = 539, [23255] = 541, [23256] = 541, [23257] = 522, [23258] = 522, [23259] = 538, [23260] = 538, [23261] = 540, [23262] = 540, [23263] = 542, [23264] = 542, [23272] = 544, [23273] = 544, [23274] = 544, [23275] = 544, [23276] = 544, [23277] = 544, [23278] = 550, [23279] = 550, [23280] = 551, [23281] = 551, [23282] = 547, [23283] = 547, [23284] = 548, [23285] = 548, [23286] = 545, [23287] = 545, [23288] = 549, [23289] = 549, [23290] = 546, [23291] = 546, [23292] = 550, [23293] = 550, [23294] = 551, [23295] = 551, [23296] = 547, [23297] = 547, [23298] = 548, [23299] = 548, [23300] = 545, [23301] = 545, [23302] = 549, [23303] = 549, [23304] = 546, [23305] = 546, [23306] = 550, [23307] = 550, [23308] = 551, [23309] = 551, [23310] = 547, [23311] = 547, [23312] = 548, [23313] = 548, [23314] = 545, [23315] = 545, [23316] = 549, [23317] = 549, [23318] = 546, [23319] = 546, [23324] = 785, [23482] = 560, [23484] = 560, [23487] = 560, [23488] = 560, [23489] = 560, [23490] = 561, [23491] = 561, [23493] = 561, [23494] = 561, [23506] = 562, [23507] = 562, [23508] = 562, [23509] = 563, [23510] = 563, [23511] = 563, [23512] = 563, [23513] = 564, [23514] = 564, [23515] = 564, [23516] = 564, [23517] = 569, [23518] = 569, [23519] = 569, [23520] = 566, [23521] = 566, [23522] = 566, [23523] = 565, [23524] = 565, [23525] = 565, [24249] = 570, [24255] = 570, [24261] = 571, [24262] = 559, [24263] = 572, [24264] = 571, [24266] = 559, [24267] = 572, [24544] = 567, [24545] = 567, [24546] = 567, [24547] = 567, [24549] = 567, [24552] = 568, [24553] = 568, [24554] = 568, [24555] = 568, [24556] = 568, [25654] = 611, [25655] = 611, [25656] = 611, [25657] = 611, [25659] = 612, [25660] = 612, [25661] = 612, [25662] = 612, [25668] = 613, [25669] = 613, [25670] = 613, [25671] = 613, [25673] = 614, [25674] = 614, [25675] = 614, [25676] = 614, [25685] = 573, [25686] = 573, [25687] = 573, [25689] = 574, [25690] = 574, [25691] = 574, [25692] = 576, [25693] = 576, [25694] = 576, [25695] = 575, [25696] = 575, [25697] = 575, [25830] = 577, [25831] = 577, [25832] = 577, [25833] = 577, [25834] = 577, [25854] = 579, [25855] = 579, [25856] = 579, [25857] = 579, [25858] = 579, [25997] = 578, [25998] = 578, [25999] = 578, [26000] = 578, [26001] = 578, [27465] = 658, [27468] = 637, [27469] = 580, [27470] = 580, [27471] = 580, [27472] = 580, [27473] = 580, [27474] = 650, [27475] = 653, [27497] = 661, [27508] = 647, [27509] = 620, [27510] = 630, [27528] = 660, [27531] = 659, [27535] = 623, [27536] = 662, [27537] = 644, [27702] = 582, [27703] = 582, [27704] = 582, [27705] = 582, [27706] = 582, [27707] = 581, [27708] = 581, [27709] = 581, [27710] = 581, [27711] = 581, [27713] = 660, [27737] = 637, [27738] = 647, [27739] = 623, [27771] = 661, [27775] = 662, [27776] = 620, [27778] = 644, [27796] = 658, [27797] = 659, [27801] = 650, [27802] = 630, [27803] = 653, [27837] = 659, [27838] = 647, [27839] = 623, [27870] = 661, [27873] = 637, [27874] = 650, [27875] = 662, [27879] = 583, [27880] = 583, [27881] = 583, [27882] = 583, [27883] = 583, [27907] = 658, [27908] = 620, [27909] = 630, [27936] = 660, [27948] = 644, [27977] = 653, [28126] = 584, [28127] = 584, [28128] = 584, [28129] = 584, [28130] = 584, [28136] = 585, [28137] = 585, [28138] = 585, [28139] = 585, [28140] = 585, [28189] = 737, [28191] = 658, [28192] = 660, [28193] = 658, [28202] = 637, [28203] = 623, [28204] = 620, [28205] = 653, [28224] = 659, [28225] = 661, [28228] = 650, [28229] = 647, [28230] = 662, [28231] = 630, [28232] = 644, [28264] = 659, [28275] = 650, [28278] = 647, [28285] = 623, [28331] = 586, [28332] = 586, [28333] = 586, [28334] = 586, [28335] = 586, [28348] = 637, [28349] = 630, [28350] = 653, [28401] = 660, [28403] = 661, [28413] = 662, [28414] = 620, [28415] = 644, [28613] = 595, [28614] = 595, [28615] = 595, [28616] = 595, [28617] = 595, [28618] = 601, [28619] = 601, [28620] = 601, [28622] = 601, [28623] = 601, [28624] = 591, [28625] = 591, [28626] = 591, [28627] = 591, [28628] = 591, [28679] = 589, [28680] = 589, [28681] = 589, [28683] = 589, [28684] = 605, [28685] = 605, [28686] = 605, [28687] = 605, [28688] = 605, [28689] = 593, [28690] = 593, [28691] = 593, [28692] = 593, [28693] = 593, [28694] = 603, [28695] = 603, [28696] = 603, [28697] = 603, [28698] = 603, [28699] = 590, [28700] = 590, [28701] = 590, [28702] = 590, [28703] = 590, [28704] = 597, [28705] = 597, [28706] = 597, [28707] = 597, [28708] = 597, [28709] = 607, [28710] = 607, [28711] = 607, [28712] = 607, [28713] = 607, [28714] = 599, [28715] = 599, [28716] = 599, [28717] = 599, [28718] = 599, [28719] = 609, [28720] = 609, [28721] = 609, [28722] = 609, [28723] = 609, [28724] = 589, [28805] = 596, [28806] = 596, [28807] = 596, [28808] = 596, [28809] = 596, [28811] = 602, [28812] = 602, [28813] = 602, [28814] = 602, [28815] = 602, [28817] = 592, [28818] = 592, [28819] = 592, [28820] = 592, [28821] = 592, [28831] = 587, [28832] = 587, [28833] = 587, [28834] = 587, [28835] = 587, [28836] = 606, [28837] = 606, [28838] = 606, [28839] = 606, [28840] = 606, [28841] = 594, [28842] = 594, [28843] = 594, [28844] = 594, [28845] = 594, [28846] = 604, [28847] = 604, [28848] = 604, [28849] = 604, [28850] = 604, [28851] = 588, [28852] = 588, [28853] = 588, [28854] = 588, [28855] = 588, [28856] = 598, [28857] = 598, [28858] = 598, [28859] = 598, [28860] = 598, [28861] = 608, [28862] = 608, [28863] = 608, [28864] = 608, [28865] = 608, [28866] = 600, [28867] = 600, [28868] = 600, [28869] = 600, [28870] = 600, [28871] = 610, [28872] = 610, [28873] = 610, [28874] = 610, [28875] = 610, [28963] = 645, [28964] = 645, [28966] = 645, [28967] = 645, [28968] = 645, [29011] = 654, [29012] = 654, [29015] = 654, [29016] = 654, [29017] = 654, [29019] = 655, [29020] = 655, [29021] = 655, [29022] = 655, [29023] = 655, [29028] = 631, [29029] = 631, [29030] = 631, [29031] = 631, [29032] = 631, [29033] = 632, [29034] = 632, [29035] = 632, [29036] = 632, [29037] = 632, [29038] = 633, [29039] = 633, [29040] = 633, [29042] = 633, [29043] = 633, [29044] = 621, [29045] = 621, [29046] = 621, [29047] = 621, [29048] = 621, [29049] = 663, [29050] = 663, [29053] = 663, [29054] = 663, [29055] = 663, [29056] = 664, [29057] = 664, [29058] = 664, [29059] = 664, [29060] = 664, [29061] = 624, [29062] = 624, [29063] = 624, [29064] = 624, [29065] = 624, [29066] = 625, [29067] = 625, [29068] = 625, [29069] = 625, [29070] = 625, [29071] = 626, [29072] = 626, [29073] = 626, [29074] = 626, [29075] = 626, [29076] = 648, [29077] = 648, [29078] = 648, [29079] = 648, [29080] = 648, [29081] = 651, [29082] = 651, [29083] = 651, [29084] = 651, [29085] = 651, [29086] = 638, [29087] = 638, [29088] = 638, [29089] = 638, [29090] = 638, [29091] = 639, [29092] = 639, [29093] = 639, [29094] = 639, [29095] = 639, [29096] = 640, [29097] = 640, [29098] = 640, [29099] = 640, [29100] = 640, [29515] = 616, [29516] = 616, [29517] = 616, [29519] = 617, [29520] = 617, [29521] = 617, [29522] = 618, [29523] = 618, [29524] = 618, [29525] = 619, [29526] = 619, [29527] = 619, [29594] = 718, [29595] = 718, [29596] = 718, [29597] = 718, [29598] = 718, [29599] = 718, [29600] = 697, [29601] = 697, [29602] = 697, [29603] = 697, [29604] = 697, [29605] = 697, [29606] = 717, [29607] = 717, [29608] = 717, [29609] = 717, [29610] = 717, [29611] = 717, [29612] = 698, [29613] = 698, [29614] = 698, [29615] = 698, [29616] = 698, [29617] = 698, [30113] = 656, [30114] = 656, [30115] = 656, [30116] = 656, [30117] = 656, [30118] = 657, [30119] = 657, [30120] = 657, [30121] = 657, [30122] = 657, [30123] = 628, [30124] = 628, [30125] = 628, [30126] = 628, [30127] = 628, [30129] = 629, [30130] = 629, [30131] = 629, [30132] = 629, [30133] = 629, [30134] = 627, [30135] = 627, [30136] = 627, [30137] = 627, [30138] = 627, [30139] = 652, [30140] = 652, [30141] = 652, [30142] = 652, [30143] = 652, [30144] = 622, [30145] = 622, [30146] = 622, [30148] = 622, [30149] = 622, [30150] = 665, [30151] = 665, [30152] = 665, [30153] = 665, [30154] = 665, [30159] = 666, [30160] = 666, [30161] = 666, [30162] = 666, [30163] = 666, [30164] = 634, [30165] = 634, [30166] = 634, [30167] = 634, [30168] = 634, [30169] = 635, [30170] = 635, [30171] = 635, [30172] = 635, [30173] = 635, [30185] = 636, [30186] = 615, [30187] = 615, [30188] = 615, [30189] = 636, [30190] = 636, [30192] = 636, [30194] = 636, [30196] = 649, [30200] = 615, [30201] = 615, [30205] = 649, [30206] = 649, [30207] = 649, [30210] = 649, [30211] = 646, [30212] = 646, [30213] = 646, [30214] = 646, [30215] = 646, [30216] = 642, [30217] = 642, [30219] = 642, [30220] = 642, [30221] = 642, [30222] = 641, [30223] = 641, [30228] = 641, [30229] = 641, [30230] = 641, [30231] = 643, [30232] = 643, [30233] = 643, [30234] = 643, [30235] = 643, [30486] = 567, [30487] = 567, [30488] = 567, [30489] = 567, [30490] = 567, [30969] = 672, [30970] = 673, [30972] = 672, [30974] = 673, [30975] = 672, [30976] = 673, [30977] = 672, [30978] = 673, [30979] = 672, [30980] = 673, [30982] = 680, [30983] = 681, [30985] = 679, [30987] = 679, [30988] = 681, [30989] = 680, [30990] = 680, [30991] = 679, [30992] = 681, [30993] = 680, [30994] = 681, [30995] = 679, [30996] = 681, [30997] = 680, [30998] = 679, [31001] = 669, [31003] = 669, [31004] = 669, [31005] = 669, [31006] = 669, [31007] = 683, [31008] = 684, [31011] = 682, [31012] = 683, [31014] = 684, [31015] = 682, [31016] = 683, [31017] = 684, [31018] = 682, [31019] = 683, [31020] = 684, [31021] = 682, [31022] = 683, [31023] = 684, [31024] = 682, [31026] = 668, [31027] = 668, [31028] = 668, [31029] = 668, [31030] = 668, [31032] = 678, [31034] = 676, [31035] = 677, [31037] = 678, [31039] = 676, [31040] = 677, [31041] = 678, [31042] = 676, [31043] = 677, [31044] = 676, [31045] = 678, [31046] = 677, [31047] = 678, [31048] = 676, [31049] = 677, [31050] = 670, [31051] = 670, [31052] = 670, [31053] = 670, [31054] = 670, [31055] = 671, [31056] = 671, [31057] = 671, [31058] = 671, [31059] = 671, [31060] = 675, [31061] = 674, [31063] = 675, [31064] = 674, [31065] = 674, [31066] = 675, [31067] = 674, [31068] = 675, [31069] = 675, [31070] = 674, [31338] = 667, [31339] = 667, [31375] = 685, [31376] = 685, [31377] = 685, [31378] = 685, [31379] = 685, [31396] = 686, [31397] = 686, [31400] = 686, [31406] = 686, [31407] = 686, [31409] = 687, [31410] = 687, [31411] = 687, [31412] = 687, [31413] = 687, [31584] = 689, [31585] = 689, [31586] = 689, [31587] = 689, [31588] = 689, [31589] = 688, [31590] = 688, [31591] = 688, [31592] = 688, [31593] = 688, [31613] = 690, [31614] = 690, [31616] = 690, [31618] = 690, [31619] = 690, [31620] = 691, [31621] = 692, [31622] = 691, [31623] = 691, [31624] = 691, [31625] = 691, [31626] = 692, [31627] = 692, [31628] = 692, [31629] = 692, [31630] = 693, [31631] = 693, [31632] = 693, [31633] = 693, [31634] = 693, [31635] = 694, [31636] = 694, [31637] = 694, [31638] = 694, [31639] = 694, [31640] = 695, [31641] = 695, [31642] = 695, [31643] = 695, [31644] = 695, [31646] = 696, [31647] = 696, [31648] = 696, [31649] = 696, [31650] = 696, [31960] = 586, [31961] = 586, [31962] = 586, [31963] = 586, [31964] = 586, [31967] = 584, [31968] = 584, [31969] = 584, [31971] = 584, [31972] = 584, [31973] = 568, [31974] = 568, [31975] = 568, [31976] = 568, [31977] = 568, [31979] = 615, [31980] = 615, [31981] = 615, [31982] = 615, [31983] = 615, [31987] = 685, [31988] = 685, [31989] = 685, [31990] = 685, [31991] = 685, [31992] = 582, [31993] = 582, [31995] = 582, [31996] = 582, [31997] = 582, [31998] = 577, [31999] = 577, [32000] = 577, [32001] = 577, [32002] = 577, [32004] = 578, [32005] = 578, [32006] = 578, [32007] = 578, [32008] = 578, [32009] = 580, [32010] = 580, [32011] = 580, [32012] = 580, [32013] = 580, [32015] = 687, [32016] = 687, [32017] = 687, [32018] = 687, [32019] = 687, [32020] = 690, [32021] = 690, [32022] = 690, [32023] = 690, [32024] = 690, [32029] = 686, [32030] = 686, [32031] = 686, [32032] = 686, [32033] = 686, [32034] = 581, [32035] = 581, [32036] = 581, [32037] = 581, [32038] = 581, [32039] = 583, [32040] = 583, [32041] = 583, [32042] = 583, [32043] = 583, [32047] = 579, [32048] = 579, [32049] = 579, [32050] = 579, [32051] = 579, [32056] = 585, [32057] = 585, [32058] = 585, [32059] = 585, [32060] = 585, [32837] = 699, [32838] = 699, [32945] = 719, [32946] = 719, [33173] = 566, [33664] = 586, [33665] = 586, [33666] = 586, [33667] = 586, [33668] = 586, [33671] = 584, [33672] = 584, [33673] = 584, [33674] = 584, [33675] = 584, [33676] = 568, [33677] = 568, [33678] = 568, [33679] = 568, [33680] = 568, [33682] = 615, [33683] = 615, [33684] = 615, [33685] = 615, [33686] = 615, [33690] = 685, [33691] = 685, [33692] = 685, [33693] = 685, [33694] = 685, [33695] = 582, [33696] = 582, [33697] = 582, [33698] = 582, [33699] = 582, [33700] = 577, [33701] = 577, [33702] = 577, [33703] = 577, [33704] = 577, [33706] = 578, [33707] = 578, [33708] = 578, [33709] = 578, [33710] = 578, [33711] = 580, [33712] = 580, [33713] = 580, [33714] = 580, [33715] = 580, [33717] = 687, [33718] = 687, [33719] = 687, [33720] = 687, [33721] = 687, [33722] = 690, [33723] = 690, [33724] = 690, [33725] = 690, [33726] = 690, [33728] = 567, [33729] = 567, [33730] = 567, [33731] = 567, [33732] = 567, [33738] = 686, [33739] = 686, [33740] = 686, [33741] = 686, [33742] = 686, [33744] = 581, [33745] = 581, [33746] = 581, [33747] = 581, [33748] = 581, [33749] = 583, [33750] = 583, [33751] = 583, [33752] = 583, [33753] = 583, [33757] = 579, [33758] = 579, [33759] = 579, [33760] = 579, [33761] = 579, [33767] = 585, [33768] = 585, [33769] = 585, [33770] = 585, [33771] = 585, [33862] = 762, [33863] = 762, [33864] = 762, [33868] = 762, [33966] = 762, [33967] = 762, [33968] = 762, [33969] = 762, [34085] = 761, [34086] = 761, [34087] = 761, [34431] = 680, [34432] = 681, [34433] = 679, [34434] = 674, [34435] = 675, [34436] = 670, [34437] = 684, [34438] = 683, [34439] = 682, [34441] = 672, [34442] = 673, [34443] = 669, [34444] = 676, [34445] = 678, [34446] = 677, [34447] = 671, [34448] = 668, [34485] = 680, [34487] = 681, [34488] = 679, [34527] = 675, [34528] = 674, [34541] = 670, [34542] = 684, [34543] = 683, [34545] = 682, [34546] = 672, [34547] = 673, [34549] = 669, [34554] = 678, [34555] = 677, [34556] = 676, [34557] = 671, [34558] = 668, [34559] = 681, [34560] = 679, [34561] = 680, [34562] = 675, [34563] = 674, [34564] = 670, [34565] = 683, [34566] = 684, [34567] = 682, [34568] = 673, [34569] = 672, [34570] = 669, [34571] = 678, [34572] = 677, [34573] = 676, [34574] = 671, [34575] = 668, [34683] = 785, [34685] = 785, [34703] = 737, [34990] = 586, [34991] = 586, [34992] = 586, [34993] = 586, [34994] = 586, [34998] = 584, [34999] = 584, [35000] = 584, [35001] = 584, [35002] = 584, [35003] = 568, [35004] = 568, [35005] = 568, [35006] = 568, [35007] = 568, [35009] = 615, [35010] = 615, [35011] = 615, [35012] = 615, [35013] = 615, [35022] = 685, [35023] = 685, [35024] = 685, [35025] = 685, [35026] = 685, [35027] = 582, [35028] = 582, [35029] = 582, [35030] = 582, [35031] = 582, [35032] = 577, [35033] = 577, [35034] = 577, [35035] = 577, [35036] = 577, [35042] = 578, [35043] = 578, [35044] = 578, [35045] = 578, [35046] = 578, [35048] = 580, [35049] = 580, [35050] = 580, [35051] = 580, [35052] = 580, [35053] = 687, [35054] = 687, [35055] = 687, [35056] = 687, [35057] = 687, [35059] = 690, [35060] = 690, [35061] = 690, [35062] = 690, [35063] = 690, [35066] = 567, [35067] = 567, [35068] = 567, [35069] = 567, [35070] = 567, [35077] = 686, [35078] = 686, [35079] = 686, [35080] = 686, [35081] = 686, [35083] = 581, [35084] = 581, [35085] = 581, [35086] = 581, [35087] = 581, [35088] = 583, [35089] = 583, [35090] = 583, [35091] = 583, [35092] = 583, [35096] = 579, [35097] = 579, [35098] = 579, [35099] = 579, [35100] = 579, [35111] = 585, [35112] = 585, [35113] = 585, [35114] = 585, [35115] = 585, [35328] = 738, [35329] = 738, [35330] = 738, [35331] = 738, [35332] = 738, [35333] = 739, [35334] = 739, [35335] = 739, [35336] = 739, [35337] = 739, [35338] = 740, [35339] = 740, [35340] = 740, [35341] = 740, [35342] = 740, [35343] = 741, [35344] = 741, [35345] = 741, [35346] = 741, [35347] = 741, [35356] = 742, [35357] = 742, [35358] = 742, [35359] = 742, [35360] = 742, [35361] = 744, [35362] = 744, [35363] = 744, [35364] = 744, [35365] = 744, [35366] = 745, [35367] = 745, [35368] = 745, [35369] = 745, [35370] = 745, [35371] = 743, [35372] = 743, [35373] = 743, [35374] = 743, [35375] = 743, [35376] = 749, [35377] = 749, [35378] = 749, [35379] = 749, [35380] = 749, [35381] = 748, [35382] = 748, [35383] = 748, [35384] = 748, [35385] = 748, [35386] = 746, [35387] = 746, [35388] = 746, [35389] = 746, [35390] = 746, [35391] = 747, [35392] = 747, [35393] = 747, [35394] = 747, [35395] = 747, [35402] = 751, [35403] = 751, [35404] = 751, [35405] = 751, [35406] = 751, [35407] = 750, [35408] = 750, [35409] = 750, [35410] = 750, [35411] = 750, [35412] = 752, [35413] = 752, [35414] = 752, [35415] = 752, [35416] = 752, [35464] = 738, [35465] = 741, [35466] = 740, [35467] = 739, [35468] = 745, [35469] = 742, [35470] = 744, [35471] = 743, [35472] = 746, [35473] = 747, [35474] = 748, [35475] = 749, [35476] = 751, [35477] = 752, [35478] = 750, [37758] = 759, [37821] = 759, [38400] = 754, [38401] = 754, [38402] = 754, [38403] = 754, [38404] = 754, [38405] = 754, [38406] = 757, [38407] = 757, [38408] = 757, [38409] = 757, [38410] = 757, [38411] = 757, [38412] = 756, [38413] = 756, [38414] = 756, [38415] = 756, [38416] = 756, [38417] = 755, [38418] = 755, [38419] = 755, [38420] = 755, [38421] = 755, [38422] = 755, [38424] = 756, [38433] = 754, [38434] = 757, [38435] = 755, [38436] = 756, [38437] = 754, [38438] = 757, [38439] = 755, [38440] = 756, [38591] = 754, [38592] = 754, [39491] = 803, [39492] = 803, [39493] = 803, [39494] = 803, [39495] = 803, [39496] = 802, [39497] = 802, [39498] = 802, [39499] = 802, [39500] = 802, [39514] = 804, [39515] = 804, [39517] = 804, [39518] = 804, [39519] = 804, [39521] = 805, [39523] = 805, [39528] = 805, [39529] = 805, [39530] = 805, [39531] = 799, [39538] = 799, [39539] = 799, [39542] = 799, [39543] = 799, [39544] = 800, [39545] = 800, [39546] = 800, [39547] = 800, [39548] = 800, [39553] = 798, [39554] = 798, [39555] = 798, [39556] = 798, [39557] = 798, [39558] = 801, [39560] = 801, [39561] = 801, [39564] = 801, [39565] = 801, [39578] = 794, [39579] = 794, [39580] = 794, [39581] = 794, [39582] = 794, [39583] = 797, [39588] = 797, [39589] = 797, [39590] = 797, [39591] = 797, [39592] = 796, [39593] = 796, [39594] = 796, [39595] = 796, [39596] = 796, [39597] = 795, [39601] = 795, [39602] = 795, [39603] = 795, [39604] = 795, [39605] = 788, [39606] = 788, [39607] = 788, [39608] = 788, [39609] = 788, [39610] = 787, [39611] = 787, [39612] = 787, [39613] = 787, [39617] = 792, [39618] = 792, [39619] = 792, [39620] = 792, [39621] = 792, [39622] = 787, [39623] = 793, [39624] = 793, [39625] = 793, [39626] = 793, [39627] = 793, [39628] = 790, [39629] = 790, [39630] = 790, [39631] = 790, [39632] = 790, [39633] = 789, [39634] = 789, [39635] = 789, [39636] = 789, [39637] = 789, [39638] = 791, [39639] = 791, [39640] = 791, [39641] = 791, [39642] = 791, [40415] = 803, [40416] = 803, [40417] = 803, [40418] = 803, [40419] = 803, [40420] = 802, [40421] = 802, [40422] = 802, [40423] = 802, [40424] = 802, [40440] = 760, [40441] = 760, [40442] = 760, [40443] = 760, [40444] = 760, [40445] = 804, [40447] = 804, [40448] = 804, [40449] = 804, [40450] = 804, [40454] = 805, [40456] = 805, [40457] = 805, [40458] = 805, [40459] = 805, [40460] = 799, [40461] = 799, [40462] = 799, [40463] = 799, [40465] = 799, [40466] = 800, [40467] = 800, [40468] = 800, [40469] = 800, [40470] = 800, [40471] = 798, [40472] = 798, [40473] = 798, [40493] = 798, [40494] = 798, [40495] = 801, [40496] = 801, [40499] = 801, [40500] = 801, [40502] = 801, [40503] = 794, [40504] = 794, [40505] = 794, [40506] = 794, [40507] = 794, [40508] = 797, [40509] = 797, [40510] = 797, [40512] = 797, [40513] = 797, [40514] = 796, [40515] = 796, [40516] = 796, [40517] = 796, [40518] = 796, [40520] = 795, [40521] = 795, [40522] = 795, [40523] = 795, [40524] = 795, [40525] = 788, [40527] = 788, [40528] = 788, [40529] = 788, [40530] = 788, [40544] = 787, [40545] = 787, [40546] = 787, [40547] = 787, [40548] = 787, [40550] = 792, [40552] = 792, [40554] = 792, [40556] = 792, [40557] = 792, [40559] = 793, [40563] = 793, [40565] = 793, [40567] = 793, [40568] = 793, [40569] = 790, [40570] = 790, [40571] = 790, [40572] = 790, [40573] = 790, [40574] = 789, [40575] = 789, [40576] = 789, [40577] = 789, [40578] = 789, [40579] = 791, [40580] = 791, [40581] = 791, [40583] = 791, [40584] = 791, [40778] = 765, [40779] = 768, [40780] = 766, [40781] = 768, [40782] = 766, [40783] = 765, [40784] = 768, [40785] = 766, [40786] = 765, [40787] = 768, [40788] = 766, [40789] = 765, [40790] = 765, [40791] = 768, [40792] = 766, [40797] = 765, [40798] = 766, [40799] = 768, [40801] = 765, [40802] = 766, [40803] = 768, [40804] = 765, [40805] = 766, [40806] = 768, [40807] = 765, [40808] = 766, [40809] = 768, [40810] = 765, [40811] = 768, [40812] = 766, [40816] = 765, [40817] = 768, [40818] = 766, [40819] = 765, [40820] = 768, [40821] = 766, [40823] = 765, [40824] = 768, [40825] = 766, [40826] = 765, [40827] = 768, [40828] = 766, [40829] = 765, [40830] = 768, [40831] = 766, [40836] = 765, [40837] = 768, [40838] = 766, [40840] = 765, [40841] = 768, [40842] = 766, [40844] = 765, [40845] = 768, [40846] = 766, [40847] = 765, [40848] = 768, [40849] = 766, [40850] = 765, [40851] = 768, [40852] = 766, [40856] = 765, [40857] = 768, [40858] = 766, [40859] = 765, [40860] = 768, [40861] = 766, [40862] = 765, [40863] = 768, [40864] = 766, [40866] = 765, [40868] = 768, [40869] = 766, [40870] = 765, [40871] = 768, [40872] = 766, [40898] = 767, [40904] = 767, [40905] = 767, [40907] = 767, [40910] = 767, [40918] = 767, [40925] = 767, [40926] = 767, [40927] = 767, [40928] = 767, [40930] = 767, [40931] = 767, [40932] = 767, [40933] = 767, [40934] = 767, [40936] = 767, [40937] = 767, [40938] = 767, [40939] = 767, [40940] = 767, [40960] = 767, [40961] = 767, [40962] = 767, [40963] = 767, [40964] = 767, [40986] = 771, [40987] = 769, [40988] = 771, [40989] = 769, [40990] = 771, [40991] = 769, [40992] = 771, [40993] = 769, [40994] = 771, [40995] = 769, [40998] = 771, [40999] = 771, [41000] = 771, [41001] = 771, [41002] = 771, [41004] = 769, [41005] = 769, [41006] = 769, [41007] = 769, [41008] = 769, [41010] = 771, [41011] = 771, [41012] = 771, [41013] = 771, [41014] = 771, [41016] = 769, [41017] = 769, [41018] = 769, [41019] = 769, [41020] = 769, [41023] = 771, [41024] = 771, [41025] = 771, [41026] = 771, [41027] = 771, [41028] = 771, [41030] = 769, [41031] = 769, [41032] = 769, [41033] = 769, [41034] = 769, [41036] = 771, [41037] = 771, [41038] = 771, [41039] = 771, [41041] = 769, [41042] = 769, [41043] = 769, [41044] = 769, [41045] = 769, [41078] = 770, [41079] = 770, [41080] = 770, [41081] = 770, [41082] = 770, [41084] = 772, [41085] = 772, [41086] = 772, [41087] = 772, [41088] = 772, [41134] = 770, [41135] = 770, [41136] = 770, [41137] = 770, [41138] = 770, [41140] = 772, [41141] = 772, [41142] = 772, [41143] = 772, [41144] = 772, [41148] = 770, [41149] = 770, [41150] = 770, [41151] = 770, [41152] = 770, [41154] = 772, [41155] = 772, [41156] = 772, [41157] = 772, [41158] = 772, [41160] = 770, [41162] = 770, [41198] = 770, [41199] = 770, [41200] = 770, [41202] = 772, [41203] = 772, [41204] = 772, [41205] = 772, [41206] = 772, [41208] = 770, [41209] = 770, [41210] = 770, [41211] = 770, [41212] = 770, [41214] = 772, [41215] = 772, [41216] = 772, [41217] = 772, [41218] = 772, [41268] = 773, [41269] = 773, [41270] = 773, [41271] = 773, [41272] = 773, [41273] = 773, [41274] = 773, [41275] = 773, [41276] = 773, [41278] = 774, [41279] = 774, [41280] = 774, [41281] = 774, [41282] = 774, [41284] = 773, [41286] = 773, [41287] = 773, [41288] = 773, [41290] = 774, [41291] = 774, [41292] = 774, [41293] = 774, [41294] = 774, [41296] = 773, [41297] = 773, [41298] = 773, [41299] = 773, [41301] = 774, [41302] = 774, [41303] = 774, [41304] = 774, [41305] = 774, [41308] = 773, [41309] = 773, [41310] = 773, [41311] = 773, [41313] = 774, [41314] = 774, [41315] = 774, [41316] = 774, [41317] = 774, [41319] = 773, [41320] = 773, [41321] = 773, [41322] = 773, [41324] = 774, [41325] = 774, [41326] = 774, [41327] = 774, [41328] = 774, [41347] = 816, [41348] = 816, [41349] = 816, [41350] = 816, [41351] = 816, [41352] = 816, [41353] = 816, [41354] = 816, [41512] = 763, [41513] = 763, [41515] = 763, [41516] = 819, [41519] = 763, [41520] = 763, [41521] = 763, [41522] = 763, [41523] = 763, [41525] = 763, [41528] = 763, [41543] = 764, [41544] = 764, [41545] = 764, [41546] = 764, [41548] = 764, [41549] = 764, [41550] = 764, [41551] = 764, [41553] = 764, [41554] = 764, [41555] = 764, [41643] = 776, [41644] = 776, [41645] = 776, [41646] = 776, [41647] = 776, [41648] = 776, [41649] = 776, [41650] = 776, [41651] = 776, [41653] = 776, [41654] = 776, [41655] = 776, [41656] = 776, [41658] = 775, [41659] = 775, [41660] = 775, [41661] = 775, [41662] = 775, [41664] = 775, [41665] = 775, [41666] = 775, [41667] = 775, [41668] = 775, [41670] = 776, [41671] = 776, [41672] = 776, [41673] = 776, [41675] = 775, [41676] = 775, [41677] = 775, [41678] = 775, [41679] = 775, [41681] = 776, [41682] = 776, [41683] = 776, [41684] = 776, [41712] = 775, [41713] = 775, [41714] = 775, [41715] = 775, [41716] = 775, [41765] = 776, [41766] = 776, [41767] = 776, [41768] = 776, [41770] = 775, [41771] = 775, [41772] = 775, [41773] = 775, [41774] = 775, [41847] = 777, [41848] = 777, [41849] = 777, [41850] = 777, [41851] = 777, [41852] = 777, [41853] = 777, [41854] = 777, [41855] = 777, [41857] = 777, [41858] = 777, [41859] = 777, [41860] = 777, [41862] = 777, [41863] = 777, [41864] = 777, [41865] = 777, [41867] = 777, [41868] = 777, [41869] = 777, [41870] = 777, [41872] = 777, [41873] = 777, [41874] = 777, [41875] = 777, [41912] = 778, [41913] = 778, [41914] = 778, [41915] = 778, [41916] = 778, [41918] = 778, [41919] = 778, [41920] = 778, [41921] = 778, [41922] = 778, [41924] = 778, [41925] = 778, [41926] = 778, [41927] = 778, [41928] = 778, [41930] = 778, [41931] = 778, [41933] = 778, [41934] = 778, [41935] = 778, [41937] = 778, [41938] = 778, [41939] = 778, [41940] = 778, [41941] = 778, [41943] = 779, [41944] = 779, [41945] = 779, [41946] = 779, [41947] = 779, [41949] = 779, [41950] = 779, [41951] = 779, [41953] = 779, [41954] = 779, [41956] = 779, [41957] = 779, [41958] = 779, [41959] = 779, [41960] = 779, [41962] = 779, [41963] = 779, [41964] = 779, [41965] = 779, [41966] = 779, [41968] = 779, [41969] = 779, [41970] = 779, [41971] = 779, [41972] = 779, [41990] = 780, [41991] = 780, [41992] = 780, [41993] = 780, [41994] = 780, [41995] = 780, [41996] = 780, [41997] = 780, [41998] = 780, [41999] = 780, [42000] = 780, [42001] = 780, [42002] = 780, [42003] = 780, [42004] = 780, [42005] = 780, [42006] = 780, [42007] = 780, [42008] = 780, [42009] = 780, [42010] = 780, [42011] = 780, [42012] = 780, [42013] = 780, [42014] = 780, [42015] = 780, [42016] = 780, [42017] = 780, [42018] = 780, [42019] = 780, [42625] = 567, [42626] = 567, [42627] = 567, [42628] = 567, [42629] = 567, [42630] = 583, [42631] = 583, [42632] = 583, [42633] = 583, [42634] = 583, [42635] = 690, [42636] = 690, [42637] = 690, [42638] = 690, [42639] = 690, [42654] = 768, [42655] = 768, [42656] = 768, [42657] = 768, [42658] = 768, [42659] = 580, [42660] = 580, [42661] = 580, [42662] = 580, [42663] = 580, [42664] = 686, [42665] = 686, [42666] = 686, [42667] = 686, [42668] = 686, [42669] = 578, [42670] = 578, [42671] = 578, [42672] = 578, [42673] = 578, [42674] = 586, [42675] = 586, [42676] = 586, [42677] = 586, [42678] = 586, [42680] = 685, [42681] = 685, [42682] = 685, [42683] = 685, [42684] = 685, [42685] = 585, [42686] = 585, [42687] = 585, [42688] = 585, [42689] = 585, [42690] = 577, [42691] = 577, [42692] = 577, [42693] = 577, [42694] = 577, [42695] = 577, [42696] = 577, [42697] = 577, [42698] = 577, [42699] = 577, [42703] = 687, [42704] = 687, [42705] = 687, [42706] = 687, [42707] = 687, [42708] = 581, [42709] = 581, [42710] = 581, [42711] = 581, [42712] = 581, [42713] = 579, [42714] = 579, [42715] = 579, [42716] = 579, [42717] = 579, [42718] = 615, [42719] = 615, [42720] = 615, [42721] = 615, [42722] = 615, [42723] = 814, [42724] = 814, [42725] = 814, [42726] = 814, [42727] = 814, [42728] = 814, [42729] = 814, [42730] = 814, [43068] = 784, [43069] = 784, [43070] = 784, [43071] = 784, [43072] = 781, [43073] = 781, [43074] = 781, [43075] = 781, [43076] = 782, [43077] = 782, [43078] = 782, [43079] = 782, [43080] = 783, [43081] = 783, [43082] = 783, [43083] = 783, [43260] = 813, [43261] = 815, [43262] = 815, [43263] = 815, [43264] = 815, [43265] = 815, [43266] = 815, [43271] = 815, [43273] = 815, [43433] = 813, [43434] = 813, [43435] = 813, [43436] = 813, [43437] = 813, [43438] = 813, [43439] = 813, [43442] = 818, [43443] = 818, [43444] = 818, [43445] = 818, [43446] = 818, [43447] = 818, [43448] = 818, [43449] = 818, [43450] = 817, [43451] = 817, [43452] = 817, [43453] = 817, [43454] = 817, [43455] = 817, [43456] = 817, [43457] = 817, [43727] = 801, [43728] = 801, [43729] = 801, [43730] = 801, [43731] = 801, [43732] = 805, [43733] = 804, [43734] = 794, [43735] = 794, [43736] = 794, [43737] = 794, [43738] = 794, [43739] = 788, [43740] = 787, [43741] = 788, [43742] = 787, [43743] = 788, [43744] = 788, [43745] = 787, [43746] = 788, [43747] = 787, [43748] = 788, [43749] = 799, [43750] = 799, [43751] = 799, [43752] = 799, [43753] = 799, [43754] = 799, [43755] = 799, [43756] = 799, [43757] = 799, [43758] = 799, [43759] = 799, [43760] = 799, [43761] = 799, [43762] = 795, [43763] = 796, [43764] = 796, [43765] = 796, [43766] = 796, [43767] = 796, [43768] = 797, [43769] = 796, [43770] = 796, [43771] = 797, [43772] = 797, [43773] = 796, [43774] = 795, [43775] = 795, [43776] = 795, [43777] = 803, [43778] = 803, [43779] = 803, [43780] = 803, [43781] = 803, [43782] = 804, [43783] = 805, [43784] = 804, [43785] = 805, [43786] = 805, [43787] = 802, [43788] = 802, [43789] = 802, [43790] = 802, [43791] = 802, [43792] = 805, [43793] = 791, [43794] = 789, [43795] = 791, [43796] = 789, [43797] = 790, [43798] = 790, [43799] = 791, [43800] = 790, [43801] = 789, [43802] = 791, [43803] = 789, [43804] = 791, [43805] = 789, [43806] = 790, [43807] = 790, [43808] = 804, [43809] = 792, [43810] = 804, [43811] = 793, [43812] = 793, [43813] = 792, [43814] = 793, [43815] = 792, [43816] = 793, [43817] = 792, [43818] = 793, [43819] = 792, [43820] = 799, [43822] = 799, [43969] = 819, [43970] = 819, [43971] = 819, [43972] = 819, [43973] = 819, [43974] = 819, [43975] = 819, [44211] = 763, [44436] = 756, [44437] = 756, [44440] = 757, [44441] = 757, [44443] = 755, [44444] = 755, [45335] = 835, [45336] = 835, [45337] = 835, [45338] = 835, [45339] = 835, [45340] = 834, [45341] = 834, [45342] = 834, [45343] = 834, [45344] = 834, [45345] = 829, [45346] = 829, [45347] = 829, [45348] = 829, [45349] = 829, [45350] = 828, [45351] = 828, [45352] = 828, [45353] = 828, [45354] = 828, [45355] = 827, [45356] = 827, [45357] = 827, [45358] = 827, [45359] = 827, [45360] = 838, [45361] = 838, [45362] = 838, [45363] = 838, [45364] = 838, [45365] = 836, [45367] = 836, [45368] = 836, [45369] = 836, [45370] = 822, [45371] = 822, [45372] = 822, [45373] = 822, [45374] = 822, [45375] = 820, [45376] = 820, [45377] = 820, [45379] = 820, [45380] = 820, [45381] = 821, [45382] = 821, [45383] = 821, [45384] = 821, [45385] = 821, [45386] = 833, [45387] = 833, [45388] = 833, [45389] = 833, [45390] = 833, [45391] = 832, [45392] = 832, [45393] = 832, [45394] = 832, [45395] = 832, [45396] = 826, [45397] = 826, [45398] = 826, [45399] = 826, [45400] = 826, [45401] = 825, [45402] = 825, [45403] = 825, [45404] = 825, [45405] = 825, [45406] = 824, [45408] = 824, [45409] = 824, [45410] = 824, [45411] = 824, [45412] = 823, [45413] = 823, [45414] = 823, [45415] = 823, [45416] = 823, [45417] = 837, [45419] = 837, [45420] = 837, [45421] = 837, [45422] = 837, [45424] = 831, [45425] = 831, [45426] = 831, [45427] = 831, [45428] = 831, [45429] = 830, [45430] = 830, [45431] = 830, [45432] = 830, [45433] = 830, [46111] = 834, [46113] = 834, [46115] = 834, [46116] = 834, [46117] = 834, [46118] = 835, [46119] = 835, [46120] = 835, [46121] = 835, [46122] = 835, [46123] = 826, [46124] = 826, [46125] = 826, [46126] = 826, [46127] = 826, [46129] = 836, [46130] = 836, [46131] = 836, [46132] = 836, [46133] = 836, [46134] = 836, [46135] = 837, [46136] = 837, [46137] = 837, [46139] = 837, [46140] = 837, [46141] = 838, [46142] = 838, [46143] = 838, [46144] = 838, [46145] = 838, [46146] = 830, [46148] = 830, [46149] = 830, [46150] = 830, [46151] = 830, [46152] = 820, [46153] = 820, [46154] = 820, [46155] = 820, [46156] = 820, [46157] = 827, [46158] = 827, [46159] = 827, [46160] = 827, [46161] = 827, [46162] = 831, [46163] = 832, [46164] = 831, [46165] = 832, [46166] = 831, [46167] = 831, [46168] = 832, [46169] = 831, [46170] = 832, [46172] = 832, [46173] = 821, [46174] = 821, [46175] = 821, [46176] = 821, [46177] = 821, [46178] = 822, [46179] = 822, [46180] = 822, [46181] = 822, [46182] = 822, [46183] = 829, [46184] = 829, [46185] = 829, [46186] = 829, [46187] = 829, [46188] = 833, [46189] = 828, [46190] = 833, [46191] = 828, [46192] = 828, [46193] = 833, [46194] = 828, [46195] = 833, [46196] = 828, [46197] = 833, [46198] = 825, [46199] = 825, [46200] = 823, [46201] = 825, [46202] = 825, [46203] = 823, [46204] = 825, [46205] = 823, [46206] = 824, [46207] = 824, [46208] = 823, [46209] = 824, [46210] = 824, [46211] = 824, [46212] = 823, [46213] = 822, [46214] = 820, [46215] = 820, [46216] = 822, [46217] = 820, [46218] = 820, [46219] = 820, [46220] = 820, [46221] = 822, [46222] = 820, [46224] = 822, [46225] = 820, [46226] = 822, [46227] = 820, [46228] = 820, [46230] = 832, [46231] = 833, [46232] = 834, [46233] = 835, [46234] = 835, [46235] = 834, [46236] = 835, [46237] = 834, [46238] = 835, [46239] = 834, [46240] = 835, [46241] = 834, [46242] = 837, [46243] = 837, [46244] = 837, [46245] = 837, [46246] = 837, [46247] = 833, [46248] = 833, [46249] = 836, [46250] = 836, [46251] = 836, [46252] = 836, [46253] = 836, [46254] = 833, [46255] = 833, [46256] = 833, [46257] = 833, [46258] = 833, [46259] = 833, [46260] = 827, [46261] = 829, [46262] = 827, [46263] = 829, [46264] = 829, [46265] = 827, [46266] = 828, [46267] = 827, [46268] = 829, [46269] = 827, [46270] = 829, [46271] = 828, [46272] = 828, [46273] = 838, [46274] = 838, [46275] = 838, [46276] = 838, [46277] = 838, [46278] = 830, [46279] = 831, [46280] = 830, [46281] = 831, [46282] = 830, [46283] = 830, [46284] = 830, [46285] = 830, [46286] = 830, [46287] = 831, [46288] = 826, [46289] = 826, [46290] = 826, [46291] = 826, [46292] = 826, [46293] = 823, [46294] = 823, [46295] = 823, [46296] = 823, [46297] = 825, [46298] = 825, [46299] = 825, [46300] = 825, [46301] = 825, [46302] = 825, [46303] = 825, [46304] = 825, [46305] = 825, [46306] = 825, [46307] = 824, [46309] = 828, [46313] = 828, [47748] = 843, [47749] = 843, [47750] = 843, [47751] = 843, [47752] = 843, [47753] = 843, [47754] = 843, [47755] = 843, [47756] = 843, [47757] = 843, [47758] = 843, [47759] = 843, [47760] = 843, [47761] = 843, [47762] = 843, [47763] = 844, [47764] = 844, [47765] = 844, [47766] = 844, [47767] = 844, [47768] = 844, [47769] = 844, [47770] = 844, [47771] = 844, [47772] = 844, [47773] = 844, [47774] = 844, [47775] = 844, [47776] = 844, [47777] = 844, [47778] = 846, [47779] = 846, [47780] = 846, [47781] = 846, [47782] = 846, [47783] = 846, [47784] = 846, [47785] = 846, [47786] = 846, [47787] = 846, [47788] = 846, [47789] = 846, [47790] = 846, [47791] = 846, [47792] = 846, [47793] = 845, [47794] = 845, [47795] = 845, [47796] = 845, [47797] = 845, [47798] = 845, [47799] = 845, [47800] = 845, [47801] = 845, [47802] = 845, [47803] = 845, [47804] = 845, [47805] = 845, [47806] = 845, [47807] = 845, [47914] = 847, [47936] = 847, [47980] = 847, [47981] = 847, [47982] = 847, [47983] = 847, [47984] = 847, [47985] = 847, [47986] = 847, [47987] = 847, [48029] = 847, [48031] = 847, [48033] = 847, [48035] = 847, [48037] = 847, [48057] = 848, [48058] = 848, [48059] = 848, [48060] = 848, [48061] = 848, [48062] = 848, [48063] = 848, [48064] = 848, [48065] = 848, [48066] = 848, [48067] = 848, [48068] = 848, [48069] = 848, [48070] = 848, [48071] = 848, [48072] = 849, [48073] = 849, [48074] = 849, [48075] = 849, [48076] = 849, [48077] = 849, [48078] = 849, [48079] = 849, [48080] = 849, [48081] = 849, [48082] = 849, [48083] = 849, [48084] = 849, [48085] = 849, [48086] = 849, [48087] = 850, [48088] = 850, [48089] = 850, [48090] = 850, [48091] = 850, [48092] = 850, [48093] = 850, [48094] = 850, [48095] = 850, [48096] = 850, [48097] = 850, [48098] = 850, [48099] = 850, [48100] = 850, [48101] = 850, [48102] = 851, [48129] = 851, [48130] = 851, [48131] = 851, [48132] = 851, [48133] = 851, [48134] = 851, [48135] = 851, [48136] = 851, [48137] = 851, [48138] = 851, [48139] = 851, [48140] = 851, [48141] = 851, [48142] = 851, [48143] = 852, [48144] = 852, [48145] = 852, [48146] = 852, [48147] = 852, [48148] = 852, [48149] = 852, [48150] = 852, [48151] = 852, [48152] = 852, [48153] = 852, [48154] = 852, [48155] = 852, [48156] = 852, [48157] = 852, [48158] = 853, [48159] = 853, [48160] = 853, [48161] = 853, [48162] = 853, [48163] = 853, [48164] = 853, [48165] = 853, [48166] = 853, [48167] = 853, [48168] = 853, [48169] = 853, [48170] = 853, [48171] = 853, [48172] = 853, [48173] = 854, [48174] = 854, [48175] = 854, [48176] = 854, [48177] = 854, [48178] = 854, [48179] = 854, [48180] = 854, [48181] = 854, [48182] = 854, [48183] = 854, [48184] = 854, [48185] = 854, [48186] = 854, [48187] = 854, [48188] = 856, [48189] = 856, [48190] = 856, [48191] = 856, [48192] = 856, [48193] = 856, [48194] = 856, [48195] = 856, [48196] = 856, [48197] = 856, [48198] = 856, [48199] = 856, [48200] = 856, [48201] = 856, [48202] = 856, [48203] = 855, [48204] = 855, [48205] = 855, [48206] = 855, [48207] = 855, [48208] = 855, [48209] = 855, [48210] = 855, [48211] = 855, [48212] = 855, [48213] = 855, [48214] = 855, [48215] = 855, [48216] = 855, [48217] = 855, [48218] = 857, [48219] = 857, [48220] = 857, [48221] = 857, [48222] = 857, [48223] = 857, [48224] = 857, [48225] = 857, [48226] = 857, [48227] = 857, [48228] = 857, [48229] = 857, [48230] = 857, [48231] = 857, [48232] = 857, [48233] = 858, [48234] = 858, [48235] = 858, [48236] = 858, [48237] = 858, [48238] = 858, [48239] = 858, [48240] = 858, [48241] = 858, [48242] = 858, [48243] = 858, [48244] = 858, [48245] = 858, [48246] = 858, [48247] = 858, [48250] = 859, [48251] = 859, [48252] = 859, [48253] = 859, [48254] = 859, [48255] = 859, [48256] = 859, [48257] = 859, [48258] = 859, [48259] = 859, [48260] = 859, [48261] = 859, [48262] = 859, [48263] = 859, [48264] = 859, [48265] = 860, [48266] = 860, [48267] = 860, [48268] = 860, [48269] = 860, [48270] = 860, [48271] = 860, [48272] = 860, [48273] = 860, [48274] = 860, [48275] = 860, [48276] = 860, [48277] = 860, [48278] = 860, [48279] = 860, [48280] = 861, [48281] = 861, [48282] = 861, [48283] = 861, [48284] = 861, [48285] = 861, [48286] = 861, [48287] = 861, [48288] = 861, [48289] = 861, [48290] = 861, [48291] = 861, [48292] = 861, [48293] = 861, [48294] = 861, [48295] = 862, [48296] = 862, [48297] = 862, [48298] = 862, [48299] = 862, [48300] = 862, [48301] = 862, [48302] = 862, [48303] = 862, [48304] = 862, [48305] = 862, [48306] = 862, [48307] = 862, [48308] = 862, [48309] = 862, [48310] = 864, [48312] = 864, [48313] = 864, [48314] = 864, [48315] = 864, [48316] = 864, [48317] = 864, [48318] = 864, [48319] = 864, [48320] = 864, [48321] = 864, [48322] = 864, [48323] = 864, [48324] = 864, [48325] = 864, [48326] = 863, [48327] = 863, [48328] = 863, [48329] = 863, [48330] = 863, [48331] = 863, [48332] = 863, [48333] = 863, [48334] = 863, [48335] = 863, [48336] = 863, [48337] = 863, [48338] = 863, [48339] = 863, [48340] = 863, [48341] = 865, [48342] = 865, [48343] = 865, [48344] = 865, [48345] = 865, [48346] = 865, [48347] = 865, [48348] = 865, [48349] = 865, [48350] = 865, [48351] = 865, [48352] = 865, [48353] = 865, [48354] = 865, [48355] = 865, [48356] = 866, [48357] = 866, [48358] = 866, [48359] = 866, [48360] = 866, [48361] = 866, [48362] = 866, [48363] = 866, [48364] = 866, [48365] = 866, [48366] = 866, [48367] = 866, [48368] = 866, [48369] = 866, [48370] = 866, [48371] = 867, [48372] = 867, [48373] = 867, [48374] = 867, [48375] = 867, [48376] = 867, [48377] = 867, [48378] = 867, [48379] = 867, [48380] = 867, [48381] = 867, [48382] = 867, [48383] = 867, [48384] = 867, [48385] = 867, [48386] = 868, [48387] = 868, [48388] = 868, [48389] = 868, [48390] = 868, [48391] = 868, [48392] = 868, [48393] = 868, [48394] = 868, [48395] = 868, [48396] = 868, [48397] = 868, [48398] = 868, [48399] = 868, [48400] = 868, [48429] = 869, [48430] = 869, [48433] = 869, [48436] = 869, [48445] = 869, [48446] = 869, [48447] = 869, [48448] = 869, [48449] = 869, [48450] = 869, [48451] = 869, [48452] = 869, [48453] = 869, [48454] = 869, [48455] = 869, [48456] = 870, [48457] = 870, [48458] = 870, [48459] = 870, [48460] = 870, [48461] = 870, [48462] = 870, [48463] = 870, [48464] = 870, [48465] = 870, [48466] = 870, [48467] = 870, [48468] = 870, [48469] = 870, [48470] = 870, [48472] = 871, [48474] = 871, [48476] = 871, [48478] = 871, [48480] = 871, [48481] = 871, [48482] = 871, [48483] = 871, [48484] = 871, [48485] = 871, [48486] = 871, [48487] = 871, [48488] = 871, [48489] = 871, [48490] = 871, [48491] = 872, [48492] = 872, [48493] = 872, [48494] = 872, [48495] = 872, [48496] = 872, [48497] = 872, [48498] = 872, [48499] = 872, [48500] = 872, [48501] = 872, [48502] = 872, [48503] = 872, [48504] = 872, [48505] = 872, [48529] = 873, [48531] = 873, [48533] = 873, [48535] = 873, [48537] = 873, [48538] = 873, [48539] = 873, [48540] = 873, [48541] = 873, [48542] = 873, [48543] = 873, [48544] = 873, [48545] = 873, [48546] = 873, [48547] = 873, [48548] = 874, [48549] = 874, [48550] = 874, [48551] = 874, [48552] = 874, [48553] = 874, [48554] = 874, [48555] = 874, [48556] = 874, [48557] = 874, [48558] = 874, [48559] = 874, [48560] = 874, [48561] = 874, [48562] = 874, [48564] = 875, [48566] = 875, [48568] = 875, [48572] = 875, [48574] = 875, [48575] = 875, [48576] = 875, [48577] = 875, [48578] = 875, [48579] = 875, [48580] = 875, [48581] = 875, [48582] = 875, [48583] = 875, [48584] = 875, [48585] = 876, [48586] = 876, [48587] = 876, [48588] = 876, [48589] = 876, [48590] = 876, [48591] = 876, [48592] = 876, [48593] = 876, [48594] = 876, [48595] = 876, [48596] = 876, [48597] = 876, [48598] = 876, [48599] = 876, [48602] = 877, [48603] = 877, [48604] = 877, [48605] = 877, [48606] = 877, [48607] = 877, [48608] = 877, [48609] = 877, [48610] = 877, [48611] = 877, [48612] = 877, [48613] = 877, [48614] = 877, [48615] = 877, [48616] = 877, [48617] = 878, [48618] = 878, [48619] = 878, [48620] = 878, [48621] = 878, [48622] = 878, [48623] = 878, [48624] = 878, [48625] = 878, [48626] = 878, [48627] = 878, [48628] = 878, [48629] = 878, [48630] = 878, [48631] = 878, [48632] = 879, [48633] = 879, [48634] = 879, [48635] = 879, [48636] = 879, [48637] = 879, [48638] = 879, [48639] = 879, [48640] = 879, [48641] = 879, [48642] = 879, [48643] = 879, [48644] = 879, [48645] = 879, [48646] = 879, [48647] = 880, [48648] = 880, [48649] = 880, [48650] = 880, [48651] = 880, [48652] = 880, [48653] = 880, [48654] = 880, [48655] = 880, [48656] = 880, [48657] = 880, [48658] = 880, [48659] = 880, [48660] = 880, [48661] = 880, [48725] = 843, [48726] = 843, [48727] = 843, [48728] = 843, [48729] = 843, [48730] = 844, [48731] = 844, [48732] = 844, [48733] = 844, [48734] = 844, [48735] = 845, [48736] = 845, [48737] = 845, [48738] = 845, [48739] = 845, [48740] = 846, [48741] = 846, [48742] = 846, [48743] = 846, [48744] = 846, [48745] = 847, [48746] = 847, [48747] = 847, [48748] = 847, [48749] = 847, [48750] = 848, [48751] = 848, [48752] = 848, [48753] = 848, [48754] = 848, [48755] = 849, [48756] = 849, [48757] = 849, [48758] = 849, [48759] = 849, [48760] = 850, [48761] = 850, [48762] = 850, [48763] = 850, [48764] = 850, [48769] = 852, [48770] = 852, [48771] = 852, [48772] = 852, [48773] = 852, [48774] = 851, [48775] = 851, [48776] = 851, [48777] = 851, [48778] = 851, [48781] = 854, [48782] = 854, [48783] = 854, [48784] = 854, [48785] = 854, [48786] = 853, [48787] = 853, [48788] = 853, [48789] = 853, [48790] = 853, [48794] = 856, [48795] = 856, [48796] = 856, [48797] = 856, [48798] = 856, [48799] = 855, [48800] = 855, [48801] = 855, [48802] = 855, [48803] = 855, [48804] = 858, [48805] = 858, [48806] = 858, [48807] = 858, [48808] = 858, [48809] = 857, [48810] = 857, [48811] = 857, [48812] = 857, [48813] = 857, [48814] = 860, [48815] = 860, [48816] = 860, [48817] = 860, [48818] = 860, [48819] = 859, [48820] = 859, [48821] = 859, [48822] = 859, [48823] = 859, [48824] = 861, [48825] = 861, [48826] = 861, [48827] = 861, [48828] = 861, [48829] = 862, [48830] = 862, [48831] = 862, [48832] = 862, [48833] = 862, [48836] = 864, [48837] = 864, [48838] = 864, [48839] = 864, [48840] = 864, [48841] = 863, [48842] = 863, [48843] = 863, [48844] = 863, [48845] = 863, [48846] = 865, [48847] = 865, [48848] = 865, [48849] = 865, [48850] = 865, [48851] = 866, [48852] = 866, [48853] = 866, [48854] = 866, [48855] = 866, [48860] = 868, [48861] = 868, [48862] = 868, [48863] = 868, [48864] = 868, [48865] = 867, [48866] = 867, [48867] = 867, [48868] = 867, [48869] = 867, [48870] = 870, [48871] = 870, [48872] = 870, [48873] = 870, [48874] = 870, [48875] = 869, [48876] = 869, [48877] = 869, [48878] = 869, [48879] = 869, [48880] = 872, [48881] = 872, [48882] = 872, [48883] = 872, [48884] = 872, [48885] = 871, [48886] = 871, [48887] = 871, [48888] = 871, [48889] = 871, [48890] = 874, [48891] = 874, [48892] = 874, [48893] = 874, [48894] = 874, [48895] = 873, [48896] = 873, [48897] = 873, [48898] = 873, [48899] = 873, [48900] = 875, [48901] = 875, [48902] = 875, [48903] = 875, [48904] = 875, [48905] = 876, [48906] = 876, [48907] = 876, [48908] = 876, [48909] = 876, [48910] = 878, [48911] = 878, [48912] = 878, [48913] = 878, [48914] = 878, [48915] = 877, [48916] = 877, [48917] = 877, [48918] = 877, [48919] = 877, [48922] = 880, [48923] = 880, [48924] = 880, [48925] = 880, [48926] = 880, [48927] = 879, [48928] = 879, [48929] = 879, [48930] = 879, [48931] = 879, [49310] = 881, [49463] = 881, [49464] = 882, [49488] = 882, [50078] = 895, [50079] = 895, [50080] = 895, [50081] = 895, [50082] = 895, [50087] = 890, [50088] = 890, [50089] = 890, [50090] = 890, [50094] = 897, [50095] = 897, [50096] = 897, [50097] = 897, [50098] = 897, [50105] = 890, [50106] = 887, [50107] = 887, [50108] = 887, [50109] = 887, [50113] = 887, [50114] = 891, [50115] = 891, [50116] = 891, [50117] = 891, [50118] = 891, [50240] = 884, [50241] = 884, [50242] = 884, [50243] = 884, [50244] = 884, [50275] = 883, [50276] = 883, [50277] = 883, [50278] = 883, [50279] = 883, [50324] = 900, [50325] = 900, [50326] = 900, [50327] = 900, [50328] = 900, [50391] = 886, [50392] = 886, [50393] = 886, [50394] = 886, [50396] = 886, [50765] = 885, [50766] = 885, [50767] = 885, [50768] = 885, [50769] = 885, [50819] = 888, [50820] = 888, [50821] = 888, [50822] = 888, [50823] = 888, [50824] = 889, [50825] = 889, [50826] = 889, [50827] = 889, [50828] = 889, [50830] = 894, [50831] = 894, [50832] = 894, [50833] = 894, [50834] = 894, [50835] = 892, [50836] = 892, [50837] = 892, [50838] = 892, [50839] = 892, [50841] = 893, [50842] = 893, [50843] = 893, [50844] = 893, [50845] = 893, [50846] = 896, [50847] = 896, [50848] = 896, [50849] = 896, [50850] = 896, [50853] = 898, [50854] = 898, [50855] = 898, [50856] = 898, [50857] = 898, [50860] = 901, [50861] = 901, [50862] = 901, [50863] = 901, [50864] = 901, [50865] = 899, [50866] = 899, [50867] = 899, [50868] = 899, [50869] = 899, [51125] = 897, [51126] = 897, [51127] = 897, [51128] = 897, [51129] = 897, [51130] = 898, [51131] = 898, [51132] = 898, [51133] = 898, [51134] = 898, [51135] = 887, [51136] = 887, [51137] = 887, [51138] = 887, [51139] = 887, [51140] = 889, [51141] = 889, [51142] = 889, [51143] = 889, [51144] = 889, [51145] = 888, [51146] = 888, [51147] = 888, [51148] = 888, [51149] = 888, [51150] = 891, [51151] = 891, [51152] = 891, [51153] = 891, [51154] = 891, [51155] = 883, [51156] = 883, [51157] = 883, [51158] = 883, [51159] = 883, [51160] = 900, [51161] = 900, [51162] = 900, [51163] = 900, [51164] = 900, [51165] = 899, [51166] = 899, [51167] = 899, [51168] = 899, [51169] = 899, [51170] = 901, [51171] = 901, [51172] = 901, [51173] = 901, [51174] = 901, [51175] = 885, [51176] = 885, [51177] = 885, [51178] = 885, [51179] = 885, [51180] = 886, [51181] = 886, [51182] = 886, [51183] = 886, [51184] = 886, [51185] = 890, [51186] = 890, [51187] = 890, [51188] = 890, [51189] = 890, [51190] = 892, [51191] = 892, [51192] = 892, [51193] = 892, [51194] = 892, [51195] = 894, [51196] = 894, [51197] = 894, [51198] = 894, [51199] = 894, [51200] = 893, [51201] = 893, [51202] = 893, [51203] = 893, [51204] = 893, [51205] = 884, [51206] = 884, [51207] = 884, [51208] = 884, [51209] = 884, [51210] = 895, [51211] = 895, [51212] = 895, [51213] = 895, [51214] = 895, [51215] = 896, [51216] = 896, [51217] = 896, [51218] = 896, [51219] = 896, [51220] = 896, [51221] = 896, [51222] = 896, [51223] = 896, [51224] = 896, [51225] = 895, [51226] = 895, [51227] = 895, [51228] = 895, [51229] = 895, [51230] = 884, [51231] = 884, [51232] = 884, [51233] = 884, [51234] = 884, [51235] = 893, [51236] = 893, [51237] = 893, [51238] = 893, [51239] = 893, [51240] = 894, [51241] = 894, [51242] = 894, [51243] = 894, [51244] = 894, [51245] = 892, [51246] = 892, [51247] = 892, [51248] = 892, [51249] = 892, [51250] = 890, [51251] = 890, [51252] = 890, [51253] = 890, [51254] = 890, [51255] = 886, [51256] = 886, [51257] = 886, [51258] = 886, [51259] = 886, [51260] = 885, [51261] = 885, [51262] = 885, [51263] = 885, [51264] = 885, [51265] = 901, [51266] = 901, [51267] = 901, [51268] = 901, [51269] = 901, [51270] = 899, [51271] = 899, [51272] = 899, [51273] = 899, [51274] = 899, [51275] = 900, [51276] = 900, [51277] = 900, [51278] = 900, [51279] = 900, [51280] = 883, [51281] = 883, [51282] = 883, [51283] = 883, [51284] = 883, [51285] = 891, [51286] = 891, [51287] = 891, [51288] = 891, [51289] = 891, [51290] = 888, [51291] = 888, [51292] = 888, [51293] = 888, [51294] = 888, [51295] = 889, [51296] = 889, [51297] = 889, [51298] = 889, [51299] = 889, [51300] = 887, [51301] = 887, [51302] = 887, [51303] = 887, [51304] = 887, [51305] = 898, [51306] = 898, [51307] = 898, [51308] = 898, [51309] = 898, [51310] = 897, [51311] = 897, [51312] = 897, [51313] = 897, [51314] = 897, [51413] = 768, [51414] = 768, [51415] = 768, [51416] = 768, [51418] = 768, [51419] = 773, [51420] = 773, [51421] = 773, [51422] = 773, [51424] = 773, [51425] = 775, [51426] = 775, [51427] = 775, [51428] = 775, [51430] = 775, [51433] = 774, [51434] = 774, [51435] = 774, [51436] = 774, [51438] = 774, [51458] = 772, [51459] = 772, [51460] = 772, [51461] = 772, [51462] = 772, [51463] = 779, [51464] = 779, [51465] = 779, [51466] = 779, [51467] = 779, [51468] = 767, [51469] = 767, [51470] = 767, [51471] = 767, [51473] = 767, [51474] = 766, [51475] = 766, [51476] = 766, [51477] = 766, [51479] = 766, [51482] = 777, [51483] = 777, [51484] = 777, [51485] = 777, [51486] = 777, [51487] = 778, [51488] = 778, [51489] = 778, [51490] = 778, [51491] = 778, [51492] = 776, [51493] = 776, [51494] = 776, [51495] = 776, [51496] = 776, [51497] = 771, [51498] = 771, [51499] = 771, [51500] = 771, [51502] = 771, [51503] = 770, [51504] = 770, [51505] = 770, [51506] = 770, [51508] = 770, [51509] = 769, [51510] = 769, [51511] = 769, [51512] = 769, [51514] = 769, [51536] = 780, [51537] = 780, [51538] = 780, [51539] = 780, [51540] = 780, [51541] = 765, [51542] = 765, [51543] = 765, [51544] = 765, [51545] = 765, [51682] = 897, [51683] = 897, [51684] = 897, [51685] = 897, [51686] = 897, [51687] = 898, [51688] = 898, [51689] = 898, [51690] = 898, [51691] = 898, [51692] = 887, [51693] = 887, [51694] = 887, [51695] = 887, [51696] = 887, [51697] = 889, [51698] = 889, [51699] = 889, [51700] = 889, [51701] = 889, [51702] = 888, [51703] = 888, [51704] = 888, [51705] = 888, [51706] = 888, [51707] = 891, [51708] = 891, [51709] = 891, [51710] = 891, [51711] = 891, [51712] = 883, [51713] = 883, [51714] = 883, [51715] = 883, [51716] = 883, [51717] = 900, [51718] = 900, [51719] = 900, [51720] = 900, [51721] = 900, [51722] = 899, [51723] = 899, [51724] = 899, [51725] = 899, [51726] = 899, [51727] = 901, [51728] = 901, [51729] = 901, [51730] = 901, [51731] = 901, [51732] = 885, [51733] = 885, [51734] = 885, [51735] = 885, [51736] = 885, [51737] = 886, [51738] = 886, [51739] = 886, [51740] = 886, [51741] = 886, [51742] = 890, [51743] = 890, [51744] = 890, [51745] = 890, [51746] = 890, [51747] = 892, [51748] = 892, [51749] = 892, [51750] = 892, [51751] = 892, [51752] = 894, [51753] = 894, [51754] = 894, [51755] = 894, [51756] = 894, [51757] = 893, [51758] = 893, [51759] = 893, [51760] = 893, [51761] = 893, [51762] = 884, [51763] = 884, [51764] = 884, [51765] = 884, [51766] = 884, [51767] = 895, [51768] = 895, [51769] = 895, [51770] = 895, [51771] = 895, [51772] = 896, [51773] = 896, [51774] = 896, [51775] = 896, [51776] = 896,
};
